%******************************************************************************
% The function SkelMusMetab_Cdot completes the calculation of dynamic mass
% balance equations with several subroutines, and return the corresponding
% values to Matlab solver.
%******************************************************************************
function [Cdot] = SkelMusMet_Cdot(t,C, WR_Exer)
%***************************** Model Inputs******************************** 
% Model inputs at each stage are same   
%**************************************************************************
% This section set the variables and vectors shared by different subroutine
%==========================================================================
% 1 Variables of basic physiological characteristics 
%--------------------------------------------------------------------------
global V_mus V_R V_W                                             % Volume of whole muscle and each fiber at rest 
global V_mus_active  V_R_active  V_W_active                      % Volume of whole tissue, Type I and Type II in exercise
global V_cyt_R V_mit_R V_cyt_W V_mit_W                           % Volume of each domain in each type
global V_BISF_active
global Qm Q                                                      % Blood flow of whole tissue at rest and in exercise
global Alpha_Vmus Alpha_Qm Alpha_Vmus_R Alpha_Vmus_W             % Enhancement coefficients of volume and blood for whole tissue   
%global WR_Exer                                                   % Work rate in moderate intensity exercise
%--------------------------------------------------------------------------
%Note: 
% 1) V_mus and Qm are the muscle volume and blood flow at rest, which are
%constant. V_mus_active and Qm_active are the activated values during exercise, respectively.
% 2) WR_Exer is the work rate in moderate intensity exercise.
%==========================================================================
global Ca Cb0 C0                                                 % Concentration for species in arterial and blood domain
%==========================================================================
%  2 Variables and parameters associated with blood species
%========================================================================== 
global SHbO2b O2bTot CO2bTot  
global AVD StO2
%==========================================================================
%  3 Variables and parameters associated with the metabolism in Type I
%========================================================================== 
global URR0_R Rflux0_R Cc0_R                                      % Resting fluxes (transport and reaction) and concentration
global Tmax_R Mm_R Lam_R Vmaxf_R Vmaxb_R Kf Kb Km nH           % Parameters in transport and reaction flux
global SMbO2m_R CMbO2m_R O2mTot_R CO2mTot_R                       % Related variables in CO2 and O2 
global URR_R Rflux_R                                         % Vectors in the calculation of transport and reaction flux
global pH_c_R pH_m_R                                              % pH in cytotosl and mitochondria                 
%----------Exercise parameters in moderate intensity  
global Alpha_t_R Alpha_r_R                                        % Parametes in moderate intensity exercise 
global Activ_r_R Activ_t_R                                        % Vectors of exercise controller in reaction and transport
%==========================================================================
%  3 Variables and parameters associated with the metabolism in Type II
%========================================================================== 
global URR0_W Rflux0_W Cc0_W                                      % Resting fluxes (transport and reaction) and concentration
global Tmax_W Mm_W Lam_W Vmaxf_W Vmaxb_W                          % Parameters in transport and reaction flux
global SMbO2m_W CMbO2m_W O2mTot_W CO2mTot_W                       % Related variables in CO2 and O2 
global URR_W Rflux_W                                              % Vectors in the calculation of transport and reaction flux 
global pH_c_W pH_m_W                                              % pH in cytotosl and mitochondria 
%---------------Exercise parameters_2 Moderate intensity--------------------  
global Alpha_t_W Alpha_r_W                                        % Parametes in moderate intensity exercise  
global Activ_r_W Activ_t_W                                        % Vectors of exercise controller in reaction and transport  

format long
%******************************************************************************
%                   Initilize the vectores in controller 
%--------------------------------------------------------------------------
%------------------------------Type I--------------------------------------
Activ_t_R    = ones(50,1);                % Transport flux
Activ_r_R    = ones(31,1);                % Reaction flux
%------------------------------Type II--------------------------------------
Activ_t_W    = ones(50,1);                % Transport flux
Activ_r_W    = ones(31,1);                % Reaction flux
%******************************************************************************
% This section defines the time of exercise start and time constant for different
% processes. 
% Note: The simulation protocol in this code is 15 min moderate intensity
%--------------------------------------------------------------------------
tstart   = 6.0;       % Initial 5 min is set as steady state  
%-------------------------------------------------------------------------
Tau_Q_E = 0.4;           % Time constant for blood flow during exercise
Tau_T_E = 0.4;           % Time constant for transport process
Tau_R_E = 0.4;           % Time constant for reaction 
%-------------------------------------------------------------------------
if (t <= tstart) 
        %------------------------General variable -------------------------
        WR=0.0;                                 % Work rate at rest
        Q = Qm;                                 % Blood flow of whole tissue
        V_bl_active =  0.07*V_mus;              % Volume of blood at rest
        V_isf_active =  0.13*V_mus;             % Volume of interstitial fluid (ISF) at rest
        V_R_active= V_R;                        % Volume of type I
        V_W_active= V_W;                        % Volume of Type II   
        %----------------Controllers in transport and reaction-------------
        Activ_t_R(1:50)  = 1*ones(50,1);        % Exercise controller of transport flux in Type I
        Activ_t_W(1:50)  = 1*ones(50,1);        % Exercise controller of transport flux in Type II
        Activ_r_R(1:31)  = 1*ones(31,1);        % Exercise controller of reaction flux in Type I
        Activ_r_W(1:31)  = 1*ones(31,1);        % Exercise controller of reaction flux in Type II
%-------------------------------------------------------------------------
else 
        %------------------------General variable -------------------------
        WR= WR_Exer; 
        Q = Qm * (1 + Alpha_Qm * WR * (1 - exp(-(t-tstart)/ Tau_Q_E)));                 % Blood flow Change
        %----------Effective volume-Blood domain
        V_bl_active = 0.07* V_mus * (1 + Alpha_Vmus  * WR * (1 - exp(-(t-tstart)/Tau_T_E)));  %Total muscle volume (L) change
        V_isf_active= 0.13* V_mus * (1 + Alpha_Vmus  * WR * (1 - exp(-(t-tstart)/Tau_T_E)));
        %---------Effective volume of Type I and Type II
        V_R_active = V_R * (1 + Alpha_Vmus_R  * WR * (1 - exp(-(t-tstart)/Tau_T_E)));  %Total muscle volume (L) change
        V_W_active = V_W * (1 + Alpha_Vmus_W  * WR * (1 - exp(-(t-tstart)/Tau_T_E)));  %Total muscle volume (L) change
        %--------------------Controllers in transport ---------------------
        Activ_t_R(1:29)  = 1 + Alpha_t_R(1:29)  * WR * (1 - exp(-(t-tstart)/Tau_T_E));% For transport between Blood and cytosol in Type I
        Activ_t_W(1:29)  = 1 + Alpha_t_W(1:29)  * WR * (1 - exp(-(t-tstart)/Tau_T_E));% For transport between Blood and cytosol in Type II
    
        Activ_t_R(30:50) = 1 + Alpha_t_R(30:50) * WR * (1 - exp(-(t-tstart)/Tau_R_E));% For transport between cytosol and mitochondria in Type I
        Activ_t_W(30:50) = 1 + Alpha_t_W(30:50) * WR * (1 - exp(-(t-tstart)/Tau_R_E));% For transport between cytosol and mitochondria in Type II
        %-----------------------Controllers in  reaction--------------------
        Activ_r_R(1:31) = 1 +  Alpha_r_R(1:31)  * WR * (1 - exp(-(t-tstart)/Tau_R_E));% For reaction flux in Type I
        Activ_r_W(1:31) = 1 +  Alpha_r_W(1:31)  * WR * (1 - exp(-(t-tstart)/Tau_R_E));% For reaction flux in Type II
        Activ_r_R(3) = 1 +  Alpha_r_R(3)  * WR * (1 - exp(-(t-tstart)/2));% For reaction flux in Type I

end

%--------------------------------------------------------------------------
% Note: The time constant Tau are physiological parameters of skeletal musle
% in exercise, which is estimated from literature. The transport process between
% blood and tissue is associated with blood and ccorresponds to the Tau
% of blood. The transport process between cytosol and mitochondria is
% associated with the intracellular reactions and corresponds to the time
% constant of reaction.
%******************************************************************************
%  This section define the dynamic muscle volume in each domain in each fiber 
% %------------------------------------------------------------------------
% Note: Most of skeletal muscle keeps rest with lower metabolic rate.
% During exercise, due to the recruitment of more muscle fiber, skeletal muscle
% can be activated and then the effect volume of skeletal muscle increase. 
% In the current model, we assume the slope (enhancement coefficient) of 
% Type I and Type II fiber same and then keep the propontional change.
%--------------------------------------------------------------------------
%              Distribution of Volume 
%  in Type I,  88% is cytosol    12% is mitochondria
%  in Type II, 92% is cytosol     8% is mitochondria
%-------------------------------------------------------------------------
%-----------------------------Type I muscle-------------------------------- 
V_cyt_R = 0.88*V_R_active;   % Cytosol volume in Type I muscle 
V_mit_R = 0.12*V_R_active;   % Mitochondria volume in Type I muscle 
%---------------------------Type II muscle-------------------------------- 
V_cyt_W = 0.92*V_W_active; % Cytosol muscle volume in Type II 
V_mit_W = 0.08*V_W_active; % Mitochondria muscle volume in Type II 
%--------------------------------------------------------------------------
%--------------------------------------------------------------------------
%Total effective muscle volume
V_BISF_active  = (V_bl_active +V_isf_active);
V_mus_active = (V_bl_active +V_isf_active) + V_R_active + V_W_active;


%******************************************************************************
% This section sets the species concentration in blood and in tissue (both
% fiber) (Cb and Cc_R, Cc_W) at "current" time. The values are generated 
% from the solver in the process to solve the ODEs. Then total O2 
% and CO2 concentrations in ARTERIAL blood, CAPILLARY/VENOUS blood, and tissue
% cells are calculated, which is done by using the external functions 
% O2Tot_Blood, O2Tot_Cells, CO2Tot_Blood and CO2Tot_Cells.
%**************************************************************************
Cb   = zeros(9,1);           % Vector of Cb for species in blood
Cc_R = zeros(50,1);          % Vector of Concentration in Type I
Cc_W = zeros(50,1);          % Vector of Concentration in Type II

Cb(1:9) = C(1:9);            % Species concentrations in blood from Vector C by solver
Cc_R(:) = C(10:59);          % Species in Type I from Vector C by solver 
Cc_W(:) = C(60:109);         % Species in Type II from Vector C by solver 
%--------------------------------------------------------------------------
%           Calculation of CO2 and O2 in blood domain
%--------------------------------------------------------------------------
CO2a = Ca(7);                % Free CO2 concentration in arterial blood (mmol/L)
CO2b = Cb(7);                % Free CO2 concentration in capillary/venous blood (mmol/L)

O2a  = Ca(8);                % Free O2 concentration in arterial blood (mmol/L)
O2b  = Cb(8);                % Free O2 concentration in capillary/venous blood (mmol/L)
%--------------------------------------------------------------------------
% Calculate CO2 in arterial and blood by subroutine "CO2Tot_Blood"
[SHbCO2a,CHbCO2a,CHCO3a,CO2aTot] = CO2Tot_Blood(CO2a);
[SHbCO2b,CHbCO2b,CHCO3b,CO2bTot] = CO2Tot_Blood(CO2b);
%--------------------------------------------------------------------------
% Calculate O2 in arterial and blood by subroutine "O2Tot_Blood"
[SHbO2a,CHbO2a,O2aTot] = O2Tot_Blood(O2a);
[SHbO2b,CHbO2b,O2bTot] = O2Tot_Blood(O2b);
%--------------------------------------------------------------------------
% Note: 
% SHbO2(CO2) is hemeoglobin (Hb) satuation of O2(CO2);
% CHbO2(CO2) is the Hb-bound O2(CO2) concentration
% O2Tot(CO2Tot) is the total O2(CO2) concentration (free + Hb- bound)
%==========================================================================
%    Calculation of CO2 and O2 in cytosol and mitochondria in each fiber
%--------------------------------------------------------------------------
%                             Type I
%--------------------------------------------------------------------------
CO2c_R = Cc_R(7);           % Free CO2 concentration in cytosol  (mmol/L)
CO2m_R = Cc_R(31);          % Free CO2 concentration in mitochondria (mmol/L)

O2c_R  = Cc_R(8);           % Free O2 concentration in cytosol (mmol/L)
O2m_R  = Cc_R(30);          % Free O2 concentration in mitochondria (mmol/L)

[CHCO3m_R,CO2mTot_R] = CO2Tot_Cells(CO2m_R);
[SMbO2m_R,CMbO2m_R,O2mTot_R] = O2Tot_Cells(O2m_R);
%--------------------------------------------------------------------------
%                           Type II
%--------------------------------------------------------------------------
CO2c_W = Cc_W(7);           % Free CO2 concentration in cytosol  (mmol/L)
CO2m_W = Cc_W(31);          % Free CO2 concentration in cytosol  (mmol/L)

O2c_W  = Cc_W(8);           % Free O2 concentration in cytosol (mmol/L)
O2m_W  = Cc_W(30);          % Free O2 concentration in mitochondria (mmol/L)

[CHCO3m_W,CO2mTot_W] = CO2Tot_Cells(CO2m_W);
[SMbO2m_W,CMbO2m_W,O2mTot_W] = O2Tot_Cells(O2m_W);
%--------------------------------------------------------------------------
% Note: 
% Due to myoglobin only exists in mitochondria, then O2(CO2) in cytosol
% are free. Then the calculation is for O2 and CO2 in mitochondria.
%--------------------------------------------------------------------------
Hct = 0.45;              
CHbTot = 5.2; 
CMbTot = 0.5; 
%--------------------------------------------------------------------------
%                Calculation of the satuation of O2 for whole tissue 
StO2 = (V_bl_active*CHbO2b/4   + V_mit_R*CMbO2m_R  + V_mit_W* CMbO2m_W)...
      /(V_bl_active*Hct*CHbTot + V_mit_R*CMbTot    + V_mit_W* CMbTot);   
%******************************************************************************
% This section adjust the reaction parameters by a subroutine due to the
% change of the dynamic pH 
%--------------------------------------------------------------------------
% Note: Because pH changes can influence free energy and corresponding
% reaction rate. We assume reaction constants(Kf, Kb, Km) are constant and 
% recalculate the forward and backward Vmax by subroutine for Type I and Type II
% respectively 
%******************************************************************************
load DeltaG

pH_c_R = -log10(Cc_R(29)/1000);              % pH in cytosol of Type I
pH_m_R = -log10(Cc_R(40)/1000);              % pH in mitochondria of type II

pH_c_W = -log10(Cc_W(29)/1000);              % pH in cytosol of Type I
pH_m_W = -log10(Cc_W(40)/1000);              % pH in mitochondria of type II

[Vmaxf_R, Vmaxb_R]= Sub_A_Vmax_H(Vmaxf_R, Vmaxb_R, Kf, Kb,pH_c_R, pH_m_R,Keq_0);   %use subroutine to recalcuate Vmax
[Vmaxf_W, Vmaxb_W]= Sub_A_Vmax_H(Vmaxf_W, Vmaxb_W, Kf, Kb,pH_c_W, pH_m_W,Keq_0);   %use subroutine to recalcuate Vmax
%******************************************************************************
% This section calculates the transport flux between blood and cytosol and
% between cytosol and mitochondria in two fibers by subroutine, respectively. 

% For transport between blood and cytosol, the uptake (UPT), release (REL), 
% uptake-release rates (URR), and arterial-venous differences (AVD) of the 9
% species are involved.VD for other 7 species can be calcuated directly, but AVD of O2
% and CO2 need to be calculated separately.
AVD = zeros(9,1);                            % Initialization of vector AVD 

AVD(1:6) = Q *(Ca(1:6)-Cb(1:6));             % AVD for first 6 species
AVD(7)   = Q *(CO2aTot - CO2bTot);           % AVD for CO2
AVD(8)   = Q *(O2aTot  - O2bTot);            % AVD for O2
AVD(9)   = Q * (Ca(9) - Cb(9));              % AVD for first 6 species

%**************************************************************************
%                           Type I
%--------------------------------------------------------------------------
UPT_R = zeros(50,1);                          % Initialization of vector UPT
REL_R = zeros(50,1);                          % Initialization of vector REL
URR_R = zeros(50,1);                          % Initialization of vector URR
%--------------------------------------------------------------------------
%                          Type II
%--------------------------------------------------------------------------
UPT_W = zeros(50,1);                          % Initialization of vector UPT
REL_W = zeros(50,1);                          % Initialization of vector REL
URR_W = zeros(50,1);                          % Initialization of vector URR

[URR_R]=Sub_B_Transport(Cb, Cc_R,Tmax_R, Mm_R, Lam_R, Activ_t_R);
[URR_W]=Sub_B_Transport(Cb, Cc_W,Tmax_W, Mm_W, Lam_W, Activ_t_W);
% Note: AV difference AVD and Transport rate URR are calculate  from
% subroutine B


%******************************************************************************
% This section calculate the reaction fluxes for the 31 reactions in each muscle 
% fibers by subroutine. 
% Note: Kf, Kb, Km and nH are in fact same in two fibers. Insulin , epinephrine 
% controller and exercise activation controllers also act as the subroutine
% parameters
%******************************************************************************
Rflux_R = zeros(31,1);                        % Reaction flux vectors
Rflux_W = zeros(31,1);                        % Reaction flux vectors

[Rflux_R]= Sub_C_Reaction(Cc_R, Vmaxf_R, Vmaxb_R, Kf, Kb, Km, nH, Activ_r_R);    
[Rflux_W]= Sub_C_Reaction(Cc_W, Vmaxf_W, Vmaxb_W, Kf, Kb, Km, nH, Activ_r_W);
%******************************************************************************
% This section calculate the net metabolic reaction rate MRR (Total_production -Total_Utilization)
% of each species in two fibers by subroutine 
%******************************************************************************
[MRR_R]= Sub_D_NetReaction(Rflux_R);
[MRR_W]= Sub_D_NetReaction(Rflux_W);
%******************************************************************************
% This section calculate the effective volume of species in each domain and 
% in each fiber.   
% Note: Basiclly effective volume of a species in a domain simply is the
% volume of the domain, except for O2 and CO2, whose effective volume is
% defined by their special mass balance equation
%******************************************************************************
Beta_IMM = 6.75;                                       % capacitance of IMM space  mol/(l mito volume)/mV
%==========================================================================
[VbeffCO2] = VeffCO2_Blood(V_bl_active,V_isf_active,Cb(7));             % Effective Volume for CO2 in blood
[VbeffO2]  = VeffO2_Blood(V_bl_active,V_isf_active,Cb(8));              % Effective Volume for O2 in blood

Vbeff = (V_bl_active + V_isf_active)*ones(9,1);                         % Vbeff is the sum of blood and ISF domain    
Vbeff(7) = VbeffCO2; 
Vbeff(8) = VbeffO2; 
%------------------------------Type I--------------------------------------
%--------------------------------------------------------------------------
Vceff_R = V_cyt_R *ones(50,1);
%--------------------------------------------------------------------------
[VmeffCO2_R] = VeffCO2_Cells(V_mit_R,Cc_R(31));           % Effective Volume for CO2 in cytosol
[VmeffO2_R]  = VeffO2_Cells(V_mit_R,Cc_R(30));            % Effective Volume for O2 in cytosol 

Vmeff_R = V_mit_R* ones(50,1);                            % Effective volume in mitochondria
Vmeff_R(31) = VmeffCO2_R;                                 % Effective volume of mitochondrial CO2
Vmeff_R(30) = VmeffO2_R;                                  % Effective volume of mitochondrial O2
Vmeff_R(50) = Beta_IMM;                                   % psedo volume of Psi 
%-----------------------------Type II--------------------------------------
Vceff_W = V_cyt_W*ones(50,1);
%--------------------------------------------------------------------------
[VmeffCO2_W] = VeffCO2_Cells(V_mit_W,Cc_W(31));           % Effective Volume for CO2 in cytosol
[VmeffO2_W]  = VeffO2_Cells(V_mit_W,Cc_W(30));            % Effective Volume for O2 in cytosol 

Vmeff_W = V_mit_W* ones(50,1);                            % Effective volume in mitochondria 
Vmeff_W(31) = VmeffCO2_W;                                 % Effective volume of mitochondrial CO2 
Vmeff_W(30) = VmeffO2_W;                                  % Effective volume of mitochondrial O2

Vmeff_W(50) = Beta_IMM;                                   % psedo volume of Psi 
%**************************************************************************
% This section calculate the dynamic mass balance (d[C]/dt)of each species of two
% fibers by subroutine 
%**************************************************************************
Cbdot = zeros(9,1);                                  % Mass balance for blood species in Type 1
%--------------------------------------------------------------------------
Cbdot(1:8) = (AVD(1:8) - URR_R(1:8)- URR_W(1:8) )./ Vbeff(1:8);                                     
Cbdot(9) = (AVD(9) - URR_R(29)- URR_W(29))/ Vbeff(9);                                     

Ccdot_R = zeros(50,1);                                 % Mass balance for tissue species in Type 1
Ccdot_W = zeros(50,1);                                 % Mass balance for tissue species in Type I1

[Ccdot_R]=Sub_E_MassBalance(Cc_R, MRR_R,URR_R, Vceff_R, Vmeff_R);
[Ccdot_W]=Sub_E_MassBalance(Cc_W, MRR_W,URR_W, Vceff_W, Vmeff_W);

%----------------------------
Cdot = [Cbdot; Ccdot_R; Ccdot_W];

%******************************************************************************
%                       END OF DIFFERENTIAL EQUATIONS
%******************************************************************************

%********* START OF OTHER SUBFUNCTIONS USED IN THIS FUNCTION *******************

%******************************************************************************
% Calculation of total CO2 concentration in blood (pH in plasma and RBC is 
% assumed to be constant; equal to 7.4 plasma and 7.24 in RBC).
%******************************************************************************

function [SHbCO2,CHbCO2,CHCO3,CO2Tot] = CO2Tot_Blood(CO2)
Hct = 0.45;                     % Standard hematocrit
CHbrbc = 5.2;                   % Concentration of hemoglobin in RBC (mM)
CHbCO2Max = 4*Hct*CHbrbc;       % HbCO2 concentration in blood at 100% HbO2 saturation (mM)
pHpl = 7.4;                     % Standard pH in plasma
pHrbc = 7.24;                   % Standard pH in RBC
CHpl = 10^(-pHpl+3);            % H+ concentration in plasma (mM)
CHrbc = 10^(-pHrbc+3);          % H+ concentration in RBC (mM)
Rrbc = CHpl/CHrbc;              % Gibb-Donnan equilibrium constant
KeqCO2hyd = 7.94e-4;            % Equilibrium constant for CO2 hydration (mM)
alphaCO2 = 3.05e-2;             % Solubility of CO2 in blood (mM/mmHg)
P50HbCO2 = 265.0;               % PCO2 at 50% HbCO2 saturation (mmHg)
C50HbCO2 = alphaCO2*P50HbCO2;   % Free CO2 concentration at 50% HbCO2 saturation (mM)
KHbCO2 = 1/C50HbCO2;            % Hill constant for SHbCO2 (mM^-1)

SHbCO2 = KHbCO2*CO2/(1+KHbCO2*CO2); % HbCO2 saturation (unitless)
CHbCO2 = CHbCO2Max*SHbCO2;      % Hb-bound CO2 concentration (mM)
CHCO3pl = KeqCO2hyd*CO2/CHpl;   % Concentration of HCO3 (bicarbonate) in plasma (mM)
CHCO3rbc = Rrbc*CHCO3pl;        % Concentration of HCO3m in RBC (mM)
CHCO3 = (1-Hct)*CHCO3pl + Hct*CHCO3rbc; % Concentration of HCO3m (mM) in blood
CO2Tot = CO2 + CHbCO2 + CHCO3;  % Total CO2 concentration (mM) in blood

%******************************************************************************
% Calculation of total CO2 concentration in tissue cells (pH in cells is
% assumed to be constant; equal to 7.1).
%******************************************************************************

function [CHCO3,CO2Tot] = CO2Tot_Cells(CO2)

pH = 7.1;                       % standard pH in cells
CH = 10^(-pH+3);                % H+ concentration in cells (mM)
KeqCO2hyd = 7.94e-4;            % Equilibrium constant for CO2 hydration (mM)
CHCO3 = KeqCO2hyd*CO2/CH;       % Concentration of HCO3 (bicarbonate) in cells (mM)
CO2Tot = CO2 + CHCO3;           % Total CO2 concentration in cells (mM)

%******************************************************************************
% Calculation of total O2 concentration in blood (pH in plasma and RBC is 
% assumed to be constant; equal to 7.4 plasma and 7.24 in RBC).
%******************************************************************************

function [SHbO2,CHbO2,O2Tot] = O2Tot_Blood(O2)

Hct = 0.45;                     % Standard hematocrit (unitless)
CHbrbc = 5.2;                   % Concentration of hemoglobin in RBC (mM)
CHbO2Max = 4*Hct*CHbrbc;        % HbO2 concentration at 100% HbO2 saturation (mM)
alphaO2 = 1.35e-3;              % Solubility of O2 in plasma (mM/mmHg)
P50HbO2 = 26.8;                 % PO2 at 50% HbO2 saturation (mmHg)
C50HbO2 = alphaO2*P50HbO2;      % Free O2 concentration at 50% HbO2 saturation (mM)
nH = 2.7;                       % Hill coefficient for SHbO2 (unitless)
KHbO2 = 1/C50HbO2^nH;           % Hill constant for SHbO2 (mM^-nH)

SHbO2 = KHbO2*O2^nH/(1+KHbO2*O2^nH);  % HbO2 saturation (unitless)
CHbO2 = CHbO2Max*SHbO2;         % Hb-bound O2 concentration in blood (mM)
O2Tot = O2 + CHbO2;             % Total O2 concentration in blood (mM) 

%**************************************************************************
% Calculation of total O2 concentration in muscle cells.
%**************************************************************************

function [SMbO2,CMbO2,O2Tot] = O2Tot_Cells(O2)

CMb = 0.5;                      % Concentration of myoglobin in cells (mM)
alphaO2 = 1.35e-3;              % Solubility of O2 in cells (mM/mmHg)
P50MbO2 = 2.4;                  % PO2 at 50% MbO2 saturation (mmHg)
C50MbO2 = alphaO2*P50MbO2;      % Free O2 concentration at 50% MbO2 saturation (mM)
KMbO2 = 1/C50MbO2;              % Hill constant for SMbO2 (mM^-1)

SMbO2 = KMbO2*O2/(1+KMbO2*O2);  % MbO2 saturation in tissue cells
CMbO2 = CMb*SMbO2;              % Mb-bound O2 concentration in cells (mM)
O2Tot = O2 + CMbO2;             % Total O2 concentration in cells (mM) 

%******************************************************************************
% Calculation of effective blood volume for CO2 accounting for different forms
% of CO2 transport in blood and ISF (pH in plasma, RBC and ISF is assumed to 
% be constant; equal to 7.4 plasma, 7.24 in RBC, and 7.2 in ISF).
%******************************************************************************

function [VbeffCO2] = VeffCO2_Blood(Vb,Visf,CO2)

Hct = 0.45;                     % Standard hematocrit (unitless)
CHbrbc = 5.2;                   % Concentration of hemoglobin in RBC (mM)
CHbCO2Max = 4*Hct*CHbrbc;       % HbCO2 concentration in blood at 100% HbO2 saturation (mM)
pHrbc = 7.24;                   % Standard pH in RBC
pHpl  = 7.4;                    % Standard pH in plasma
pHisf = 7.2;                    % Standard pH in ISF
CHrbc = 10^(-pHrbc+3);          % H+ concentration in RBC (mM)
CHpl  = 10^(-pHpl+3);           % H+ concentration in plasma (mM)
CHisf = 10^(-pHisf+3);          % H+ concentration in ISF (mM)
Rrbc = CHpl/CHrbc;              % Gibb-Donnan equilibrium constant for RBC
Rcap = CHpl/CHisf;              % Gibb-Donnan equilibrium constant for capillary
KeqCO2hyd = 7.94e-4;            % Equilibrium constant for CO2 hydration (mM)
alphaCO2 = 3.05e-2;             % Solubility of CO2 in plasma (mM/mmHg)
P50HbCO2 = 265.0;               % PCO2 at 50% HbCO2 saturation (mmHg)
C50HbCO2 = alphaCO2*P50HbCO2;   % Free CO2 concentration at 50% HbCO2 saturation (mM)
KHbCO2 = 1/C50HbCO2;            % Hill constant for SHbCO2 (mM^-1)

% Calculation of derivatives of state variables w.r.t. CO2 and then effective
% blood volume for CO2...
DSHbCO2 = KHbCO2/(1+KHbCO2*CO2)^2;
DCHbCO2 = CHbCO2Max*DSHbCO2;
DCHCO3pl = KeqCO2hyd/CHpl;
DCHCO3rbc = Rrbc*DCHCO3pl;
DCHCO3isf = Rcap*DCHCO3pl;
DCHCO3bl = (1-Hct)*DCHCO3pl + Hct*DCHCO3rbc;
VbeffCO2 = Vb*(1+DCHbCO2+DCHCO3bl) + Visf*(1+DCHCO3isf);

%******************************************************************************
% Calculation of effective cells volume for CO2 accounting for different forms
% of CO2 transport in cells (pH in cells is assumed to be constant = 7.1).
%******************************************************************************

function [VceffCO2] = VeffCO2_Cells(Vc,CO2)

pH = 7.1;                       % standard pH in cells
CH = 10^(-pH+3);                % H+ concentration in cells (mM)
KeqCO2hyd = 7.94e-4;            % Equilibrium constant for CO2 hydration (mM)
alphaCO2 = 3.05e-2;             % Solubility of CO2 in cells (mM/mmHg)
DCHCO3 = KeqCO2hyd/CH;          % dCHCO3/dCO2
VceffCO2 = Vc*(1+DCHCO3);       % Effective cells volume for CO2

%******************************************************************************
% Calculation of effective blood volume for O2 accounting for different forms
% of O2 transport in blood and ISF (pH in plasma and RBC is assumed to be 
% constant; equal to 7.4 plasma and 7.24 in RBC ).
%******************************************************************************

function [VbeffO2] = VeffO2_Blood(Vb,Visf,O2)

Hct = 0.45;                     % Standard hematocrit (unitless)
CHbrbc = 5.2;                   % Concentration of hemoglobin in RBC (mM)
CHbO2Max = 4*Hct*CHbrbc;        % HbO2 concentration at 100% HbO2 saturation (mM)
alphaO2 = 1.35e-3;              % Solubility of O2 in plasma (mM/mmHg)
P50HbO2 = 26.8;                 % PO2 at 50% HbO2 saturation (mmHg)
C50HbO2 = alphaO2*P50HbO2;      % Free O2 concentration at 50% HbO2 saturation (mM)
nH = 2.7;                       % Hill coefficient for SHbO2 (unitless)
KHbO2 = 1/C50HbO2^nH;           % Hill constant for SHbO2 (mM^-nH)

% Calculation of derivatives of state variables w.r.t. O2 and then effective
% blood volume for O2... 
DSHbO2 = nH*KHbO2*O2^(nH-1)/(1+KHbO2*O2^nH)^2;
DCHbO2 = CHbO2Max*DSHbO2;
VbeffO2 = Vb*(1+DCHbO2) + Visf;

%******************************************************************************
% Calculation of effective cell volume for O2 accounting for different forms 
% of O2 transport in cells (pH in cells is assumed to be constant = 7.1).
%******************************************************************************

function [VceffO2] = VeffO2_Cells(Vc,O2)

CMb = 0.5;               %0.5;    % Concentration of myoglobin in cells (mM)
alphaO2 = 1.35e-3;              % Solubility of O2 in cells (mM/mmHg)
P50MbO2 = 2.4;                  % PO2 at 50% MbO2 saturation (mmHg)
C50MbO2 = alphaO2*P50MbO2;      % Free O2 concentration at 50% MbO2 saturation (mM)
KMbO2 = 1/C50MbO2;              % Hill constant for SMbO2 (mM^-1)
DSMbO2 = KMbO2/(1+KMbO2*O2)^2;  % dSMbO2/dO2
VceffO2 = Vc*(1+CMb*DSMbO2);    % Effective cells volume for O2

% END OF OTHER SUBFUNCTIONS USED IN THE MAIN
% FUNCTION**************************