%**************************************************************************
%   This code is to simulate the dynamic response of skeletal muscle within
% two different fibers to moderate intensity exercise. 
  
%   By Yanjun Li, Department of Biomedical Engineering, Center of Modeling
% Integrated Metabolic System, Case Western Reserve University,

% Latest modified: May 25, 2011
%-----------------------
%   Version 10.0 for CON condition  
%   Data is for Normal subject of Krustrup's study including both tissue
%and Fiber. 
%**************************************************************************
%--------------------------------------------------------------------------
%      Some suffix used in the defination of variables in the code
%-------------------------Index of variables:------------------------------
% R       Type I/red/slow fibers 
% W       Type II/white/fast fibers
%--------------------------------------------------------------------------
% c       Cytosol 
% m       Mitochondria
%-------w-------------------------------------------------------------------
% r       Reaction
% t       Transport  
%--------------------------------------------------------------------------
clf
clear all
close all
clc

format long
%*******************************************************************************
%**************************************************************************
% This section set the variables and vectors shared by different
% subroutines
%==========================================================================
% 1 Variables of basic physiological characteristics 
%--------------------------------------------------------------------------
global V_mus V_R V_W                                              % Volume of whole muscle 
global V_mus_active  V_R_active  V_W_active                       % Volume of whole tissue, Type I and Type II in exercise
global V_cyt_R V_mit_R V_cyt_W V_mit_W                           % Volume of each domain in each type
global V_BISF_active
global Qm Q                                                       % Blood flow of whole tissue at rest and in exercise
global Alpha_Vmus Alpha_Qm Alpha_Vmus_R Alpha_Vmus_W              % Enhancement coefficients of volume and blood for whole tissue     
%global WR_Exer                                                    % Work rate in moderate intensity exercise
%--------------------------------------------------------------------------
% Note: 
% 1) V_mus and Qm are the muscle volume and blood flow at rest, which are
%constant. V_mus_active and Q are the activated muscle volume and blood flow
%during exercise, respectively.
% 2) WR_Exer is the work rate in moderate intensity exercise. 
%==========================================================================
global Ca Cb0 C0                                                  % Concentration for species in arterial and blood domain
%--------------------------------------------------------------------------
% Note: Ca is the vector for arterial species, which is constant; Cb is the
% the vector for species in blood. C0 is the vector of concentration
% including species in blood and in both fibers (cytosol and mitochondria),
% which is corresponding to the dynamic mass balance equation (Cdot). C0
% values are transfered to Matlab solver, which can solve the ODE and give
% the dynamics of species concentrations.
%==========================================================================
%  2 Variables and parameters associated with blood species
%========================================================================== 
global SHbO2b O2bTot CO2bTot                                      % HbO2 saturation, total concentration of O2 and CO2 in blood
global AVD StO2                                                   % A-V difference in blood and averaged satuation (hemeoglobin and myoglobin for whole muscle) 
%==========================================================================
%  3 Variables and parameters associated with the metabolism in Type I
%========================================================================== 
global URR0_R Rflux0_R Cc0_R                                      % Resting fluxes (transport and reaction) and concentration
global Tmax_R Mm_R Lam_R Vmaxf_R Vmaxb_R Kf Kb Km nH              % Parameters in transport and reaction flux
global SMbO2m_R CMbO2m_R O2mTot_R CO2mTot_R                       % Related variables in CO2 and O2 
global URR_R Rflux_R                                              % Vectors in the calculation of transport and reaction flux
global pH_c_R pH_m_R                                              % pH in cytotosl and mitochondria                 
%--------------Exercise parameters in moderate intensity ------------------ 
global Alpha_t_R Alpha_r_R                                        % Parametes in moderate intensity exercise 
global Activ_r_R Activ_t_R                                        % Vectors of exercise controller in reaction and transport
%--------------------------------------------------------------------------
% Note: Parameters in transport and reaction fluxes are constant. Uptake
% rate (URR) and reaction fluxes (Rflux) are calculated. SmbO2m is the
% satuation of myoglobin, CMbO2m is Mb-bound O2 concentration in cells.
% O2mTot and CO2mTot are the total concentration of O2 and CO2 in each
% fiber. 
%==========================================================================
%  4 Variables and parameters associated with the metabolism in Type II
%========================================================================== 
global URR0_W Rflux0_W Cc0_W                                      % Resting fluxes (transport and reaction) and concentration
global Tmax_W Mm_W Lam_W Vmaxf_W Vmaxb_W                          % Parameters in transport and reaction flux
global SMbO2m_W CMbO2m_W O2mTot_W CO2mTot_W                       % Related variables in CO2 and O2 
global URR_W Rflux_W                                              % Vectors in the calculation of transport and reaction flux 
global pH_c_W pH_m_W                                              % pH in cytotosl and mitochondria 
%---------------Exercise parameters_2 Moderate intensity--------------------  
global Alpha_t_W Alpha_r_W                                        % Parametes in moderate intensity exercise  
global Activ_r_W Activ_t_W                                        % Vectors of exercise controller in reaction and transport  
%*******************************************************************************
%*******************************************************************************
% This section reads the uptake-release rates (URR) of species and metabolic 
% reaction fluxes (Rflux) in Type I(R) and Type II(W) at the resting,steady
% state. 
% Unit of fluxes  [mmol/min]
%*******************************************************************************
%------------------------------Type I fibers--------------------------------
%Initialize the vectors  
Flux0_R  = zeros(81,1);                  % Vector containing both transport and reaction flux
URR0_R   = zeros(50,1);                  % Uptake and release
Rflux0_R = zeros(31,1);                  % Reaction fluxes
%---------------------------------
load Restingflux

URR0_R(1:50)   = Flux0_R(1:50);          % Uptake/Release rate values
Rflux0_R(1:31) = Flux0_R(51:81);         % Reaction rate values
%==========================================================================
%------------------------------Type II fibers------------------------------
%Initialize the vectors
Flux0_W  = zeros(81,1);                  % Vector containing both transport and reaction flux
URR0_W   = zeros(50,1);                  % Uptake and release
Rflux0_W = zeros(31,1);                  % Reaction fluxes
%---------------------------------
URR0_W(1:50)   = Flux0_W(1:50);          % Uptake/Release rate values
Rflux0_W(1:31) = Flux0_W(51:81);         % Reaction rate values
%*******************************************************************************
%*******************************************************************************
% This section reads the arterial and blood concentration (9 species) and
% species concentration in tissue (50 species) in two muscle fibers.
% Unit of concentrations: [mmol/Kg WetWeight tissue] (1 Kg WW = L). 
%*******************************************************************************
%Initializing the vectors related to concentrations
%--------------------------------------------------------------------------
load Cc0
C0      = [Cb;Cc_R; Cc_W];            % Initial concentration vector for blood and tissue species of two fiber
Cc0_R=Cc_R;
Cc0_W=Cc_W;
Cb0=Cb; 
%--------------------------------------------------------------------------
V_R = 0.4*V_mus;                         % Volume of type I
V_W = 0.4*V_mus;                         % Volume of type II
%--------------------------------------------------------------------------
VR_cyt = 0.352;                          % Percent of volume of cytosol in type I
VR_mit = 0.048;                          % Percent of volume of mitochondria in type I
VW_cyt = 0.368;                          % Percent of volume of cytosol in type II
VW_mit = 0.032;                          % Percent of volume of mitochondria in type I

% Note: 
% C0 is the vector including species concentration in blood domain and
% in both two fibers, whose values of species concentration will be varied
% during the dynamics response to disturrb. The vector - C0 will be
% transfered to matlab solver. 
%**************************************************************************
% This section set the parameters in transport and reactions fluxes in each
% fibers 

% Note: Here we assume the MM constant in transport flux and Kf/Kb/Km in 
% reaction flux are same in two kinds of fibers, in which Kf/Kb/Km were 
% optimized previously and fixed. Exponential constant nH in specific 
% reaction controllers are same also. Tmax, Vmaxf and
% Vmaxb in two fibers are calculated based on the corresponding fluxes
%==========================================================================
% Read values from data file
%load para_r
load Para_r  % BEJ added
load para_w
%**************************************************************************
%       This section activation coefficients  
%--------------------------------------------------------------------------
load theta_R
load theta_W
%**************************************************************************
% Compare with experiment data during Moderate Exercise: Species Concentration
%**************************************************************************
load Exp_CON
% Data are obtained from Krustrup MSSE, 2004
%==========================================================================
% This section is to call the Matlab solver "ODE15" to solve the stiff
% system of diferential equations dC/dt = f(c,t), where C is of species
% concentration. The intial condition for which is defined above.

% The Matlab solver will call the key subroutine SkelMusMet.m to evaluate 
% the values of ODE of each species based on the mass balance equations, 
% which further need to call other subroutines to calcualte the fluxes, etc.    
%**************************************************************************
Tend =  27;                              % End time of integration 
Nstep = 135;                             % Number of time steps
Tstep = Tend/Nstep;                      % Time step of integration for ODE15S

Tspan = [0:Tstep:Tend];
options = odeset('RelTol',1e-10, 'AbsTol',1e-10, 'NormControl','on', ...
          'MaxStep',Tstep/10, 'InitialStep',Tstep/100, 'MaxOrder',5, ...
          'BDF','on');
%---------------------------------------------------------------
WR_Unload = 25;                          % Work rate for unloaded pedalling
WR_Cycle  = 115;                         % Work rate load on cycle ergometer for moderate intensity exercise (Approx. 60% VO2 max)
WR_Exer   = WR_Unload + WR_Cycle;        % Total work rate for exercise
      
[t,C] = ode15s(@SkelMusMet_Cdot,Tspan,C0,options, WR_Exer);

%*************************************************************************
%              This section sets for the model output 
%*************************************************************************
% 1 Define the vectors to record the dynamic values  
%==========================================================================
Q_vec =[];                               % Blood flow
V_ex  =[] ;                              % Muscle volume in exercise
Ca_mat =[];                              % Species in arterial 
Cb_mat = [];                             % Species in blood
V_R_ex =[];
V_W_ex =[];
V_BISF_ex =[]; 
%-----------------------------Fluxes--------------------------------------- 
URR_mat_R = [];                          % Uptake/Release for Type I 
Rflux_mat_R = [];                        % Reaction fluxes for Type I
Cc_mat_R = [];                           % Species in cytosol in Type I   
Cm_mat_R = [];                           % Species in mitochondria in Type I   
URR_mat_W = [];                         % Uptake/Release for Type II  
Rflux_mat_W = [];                       % Reaction fluxes for Type II
Cc_mat_W = [];                          % Species in cytosol in Type II  
Cm_mat_W = [];                          % Species in mitochondria in Type II
%==========================================================================
% 2   Write the dynamic variables data into these vectors during simulation  
%==========================================================================
for j = 1:Nstep+1
    tj = t(j);
    Cj = C(j,:)';
    [Cdotj] = SkelMusMet_Cdot(tj,Cj,WR_Exer);

    Q_vec  = [Q_vec; Q];
    V_R_ex =[V_R_ex; V_R_active];
    V_W_ex =[V_W_ex; V_W_active];    
    V_ex  = [V_ex; V_mus_active];
    V_BISF_ex=[V_BISF_ex; V_BISF_active];
    
    Ca_mat = [Ca_mat;Ca(1:9)'];                     %arterial species    
    Cb_mat = [Cb_mat; Cj(1:9)']; 
%==========================================================================
%                                   Type I
%==========================================================================
    URR_mat_R = [URR_mat_R;[URR_R(1:8)',URR_R(29),URR_R(30:40)']];
    Rflux_mat_R = [Rflux_mat_R;Rflux_R'];

    Cc_mat_R = [Cc_mat_R;Cj(10:38)'];                 %cytosol species
    Cm_mat_R = [Cm_mat_R;Cj(39:59)'];                 %mitochondria species

%==========================================================================
%                                Type II
%==========================================================================
    URR_mat_W = [URR_mat_W; [URR_W(1:8)',URR_W(29), URR_W(30:40)']];
    Rflux_mat_W = [Rflux_mat_W; Rflux_W'];
    Cc_mat_W = [Cc_mat_W; Cj(60:88)'];
    Cm_mat_W = [Cm_mat_W; Cj(89:109)'];
end
%%
Rflux_mat_W_CON = Rflux_mat_W;
Rflux_mat_R_CON = Rflux_mat_R;
V_R_ex_CON = V_R_ex; V_W_ex_CON=V_W_ex;    
Cc_mat_R_CON = Cc_mat_R; Cc_mat_W_CON = Cc_mat_W; 
Cm_mat_R_CON = Cm_mat_R; Cm_mat_W_CON = Cm_mat_W; 

save Sim_CON Rflux_mat_R_CON Rflux_mat_W_CON V_R_ex_CON V_W_ex_CON ...
     Cc_mat_R_CON Cc_mat_W_CON Cm_mat_R_CON Cm_mat_W_CON 

%% Final Plotting
size1=9; size2=3;
type1 = '--k'; type2 =':k'; type_t='k-';
figure(1)                                             % redox and phosphorylation state                    
set(figure(1),'Units','inches','Position',[0.5 1 10 8])  
% ploting the final results 
%--------------------------------------------------------------------------
subplot(3,3,1); subplot('position',[0.05 0.71 0.28 0.26]);   % tissue glycogen 
plot(t-6,(Cc_mat_R(:,11)*V_cyt_R + Cc_mat_W(:,11)*V_cyt_W)...
         /(Cc0_R(11)*V_cyt_R + Cc0_W(11) *V_cyt_W)*Cexp_Tis_CON_1 (1,1), ...
          type_t,'LineWidth',3)
%xlabel('Time, t [min]', 'FontName','Times New Roman', 'FontSize',10);
title('Tissue Glycogen', 'FontName','Times New Roman', 'FontSize',12,'FontWeight','bold');
ylabel('mmol/(kg dw)', 'FontName','Times New Roman', 'FontSize',11,'FontWeight','bold')
axis([-6 Tend-6 200 600]);
%axis 'autoy'
set(gca, 'LineWidth',2, 'FontName','Times New Roman', 'FontSize',10);
set(gca, 'XTick', [-5,0:5:20]);
set(gca, 'YTick', [200:200:600]);
set(gca,'XtickLabel',[])
hold on
errorbar(texp_Tis_CON_1-5, Cexp_Tis_CON_1 (:,1), ...
                           Cexp_Tis_ErrorL_CON_1(:,1), ...
                           Cexp_Tis_ErrorU_CON_1(:,1),...
         'ks', 'MarkerFaceColor','k', 'MarkerSize',size1, 'LineWidth',size2)
text(-4,575, 'A','FontSize',15,'FontWeight','bold')
%--------------------------------------------------------------------------
subplot(3,3,2); subplot('position',[0.38 0.71 0.28 0.26]);   % tissue lactate 
plot(t-6,(Cc_mat_R(:,3)*V_cyt_R + Cc_mat_W(:,3)*V_cyt_W)/...
          (Cc0_R(3)*V_cyt_R + Cc0_W(3) *V_cyt_W)*Cexp_Tis_CON_1 (1,2), ...
          type_t,'LineWidth',3)
%xlabel('Time, t [min]', 'FontName','Times New Roman', 'FontSize',10);
title('Tissue Lactate', 'FontName','Times New Roman', 'FontSize',12,'FontWeight','bold');
%ylabel('C(t)/C_{tis,Lac}(0)', 'FontName','Times New Roman', 'FontSize',10)
axis([-6 Tend-6 0 15]);
%axis 'autoy'
set(gca, 'LineWidth',2, 'FontName','Times New Roman', 'FontSize',10);
set(gca, 'XTick', [-5,0:5:15]);
set(gca, 'YTick', [0:5:15]);
set(gca,'XtickLabel',[])
hold on
errorbar(texp_Tis_CON_1-5, Cexp_Tis_CON_1 (:,2),...
                           Cexp_Tis_ErrorL_CON_1(:,2), ...
                           Cexp_Tis_ErrorU_CON_1(:,2),...
         'ks', 'MarkerFaceColor','k','MarkerSize',size1, 'LineWidth',size2)
text(-4,14, 'B','FontSize',15,'FontWeight','bold')
hold on
%--------------------------------------------------------------------------
subplot(3,3,3); subplot('position',[0.71 0.71 0.28 0.26]);   % tissue 
plot(t-6,(Cc_mat_R(:,20)*V_cyt_R + Cc_mat_W(:,20)*V_cyt_W)/...
         (Cc0_R(20)*V_cyt_R + Cc0_W(20) *V_cyt_W)*Cexp_Tis_CON_1 (1,3), ...
      type_t,'LineWidth',3)
%xlabel('Time, t [min]', 'FontName','Times New Roman', 'FontSize',10);
title('Tissue PCr', 'FontName','Times New Roman', 'FontSize',12,'FontWeight','bold');
%ylabel('C(t)/C(0)', 'FontName','Times New Roman',  'FontSize',10)
axis([-6 Tend-6 50.0 100]);
%axis 'autoy'
set(gca, 'LineWidth',2, 'FontName','Times New Roman', 'FontSize',10);
set(gca, 'XTick', [-5,0:5:20]);
set(gca, 'YTick', [50:20:100]);
set(gca,'XtickLabel',[])
hold on
errorbar(texp_Tis_CON_1-5, Cexp_Tis_CON_1 (:,3),...
                           Cexp_Tis_ErrorL_CON_1(:,3), ...
                           Cexp_Tis_ErrorU_CON_1(:,3), ...
         'ks', 'MarkerFaceColor','k', 'MarkerSize',size1, 'LineWidth',size2)
text(-4,96.5, 'C','FontSize',15,'FontWeight','bold')
%--------------------------------------------------------------------------
subplot(3,3,4); subplot('position',[0.05 0.39 0.28 0.26]);   % plasma lactate 
plot(t-6,Cb_mat(:,3)/Cb_mat(1,3)*Cexp_Tis_CON_1(1,4), type_t,'LineWidth',3)
%xlabel('Time, t [min]', 'FontName','Times New Roman', 'FontSize',10);
title('Plasma Lactate', 'FontName','Times New Roman', 'FontSize',12,'FontWeight','bold');
ylabel('mmol/l', 'FontName','Times New Roman','FontSize',11,'FontWeight','bold')
axis([-6 Tend-6 0.0 2]);
%axis 'autoy'
set(gca, 'LineWidth',2, 'FontName','Times New Roman', 'FontSize',10);
set(gca, 'XTick', [-5,0:5:20]);
set(gca, 'YTick', [0.0:0.5:2]);
set(gca,'XtickLabel',[])
hold on
errorbar(texp_Tis_CON_1-5, Cexp_Tis_CON_1(:,4),...
                           Cexp_Tis_ErrorL_CON_1(:,4), ...
                           Cexp_Tis_ErrorU_CON_1(:,4),...
          'ks', 'MarkerFaceColor','k','MarkerSize',size1, 'LineWidth',size2)
text(-4,1.85, 'D','FontSize',15,'FontWeight','bold')
%--------------------------------------------------------------------------
subplot(3,3,5); subplot('position',[0.38 0.39 0.28 0.26]);   % tissue RER 
set(gca,'XtickLabel',[])
VO2_R = (Rflux_mat_R(:,28) + Rflux_mat_R(:,29)).*V_R_ex/2/2;
VCO2_R= (Rflux_mat_R(:,20) + Rflux_mat_R(:,23)+ Rflux_mat_R(:,24)).*V_R_ex/2;
VO2_W = (Rflux_mat_W(:,28) + Rflux_mat_W(:,29)).*V_W_ex/2/2;
VCO2_W= (Rflux_mat_W(:,20) + Rflux_mat_W(:,23)+ Rflux_mat_W(:,24)).*V_W_ex/2;
% VO2_t = (Rflux_mat_R(:,28) + Rflux_mat_R(:,29)+ Rflux_mat_W(:,28) + Rflux_mat_W(:,29))/2;
% VCO2_t=  (Rflux_mat_R(:,20) + Rflux_mat_R(:,23)+ Rflux_mat_R(:,24))+...
%          (Rflux_mat_W(:,20) + Rflux_mat_W(:,23)+ Rflux_mat_W(:,24));
VO2_t= VO2_R+ VO2_W;      
VCO2_t= VCO2_R+ VCO2_W;      
plot(t-6, VCO2_R./VO2_R, type1,...
     t-6, VCO2_W./VO2_W, type2,...
     t-6, VCO2_t./VO2_t, type_t,...      
          'LineWidth',3)
% plot(t-6, -URR_mat_R(:,7)./URR_mat_R(:,8),type1,...
%      t-6, -URR_mat_W(:,7)./URR_mat_W(:,8),type2,...
%      t-6, -(URR_mat_R(:,7)+URR_mat_W(:,7))./(URR_mat_R(:,8)+URR_mat_W(:,8)),type_t,...
%      'LineWidth',3)
%xlabel('Time, t [min]', 'FontName','Times New Roman', 'FontSize',10);
title('RQ ','FontName','Times New Roman', 'FontSize',12,'FontWeight','bold')
ylabel('unitless', 'FontName','Times New Roman', 'FontSize',11,'FontWeight','bold');
axis([-6 Tend-6 0.5 1.0]);
%axis 'autoy'
set(gca, 'LineWidth',1.5, 'FontName','Times New Roman', 'FontSize',10);
set(gca, 'XTick', [-6,0:5:Tend-6]);
set(gca, 'YTick', [0.5:0.1:1.]);
legend('Type I','Type II','Whole Tissue')
legend('location', 'southeast')
legend('boxoff')
set(gca,'XtickLabel',[])
hold on
errorbar(texp_Tis_CON_1-5, Cexp_Tis_CON_1(:,5), ...
                           Cexp_Tis_ErrorL_CON_1(:,5), ...
                           Cexp_Tis_ErrorU_CON_1(:,5),...
         'ks', 'MarkerFaceColor','k', 'MarkerSize',size1, 'LineWidth',size2)
text(-4,0.96, 'E','FontSize',15,'FontWeight','bold')
%--------------------------------------------------------------------------
% subplot(3,3,6); subplot('position',[0.71 0.39 0.28 0.26]);   % tissue 
% set(gca,'XtickLabel',[])
%--------------------------------------------------------------------------
subplot(3,3,7); subplot('position',[0.05 0.06 0.28 0.26]);   % Glycogen
plot(t-6, Cc_mat_R(:,11)/Cc_mat_R(1,11)*Cexp_Fiber_CON_1(1,1),type1,'LineWidth',3);
hold on
errorbar(texp_Fiber_CON_1-5, Cexp_Fiber_CON_1(:,1), ...
                             Cexp_Fiber_ErrorL_CON_1(:,1), ...
                             Cexp_Fiber_ErrorU_CON_1(:,1),...
         'k^', 'MarkerFaceColor','k', 'MarkerSize',size1, 'LineWidth',size2)
hold on
plot(t-6, Cc_mat_W(:,11)/Cc_mat_W(1,11)*Cexp_Fiber_CON_1(1,2),type2,'LineWidth',3);
hold on 
%legend('Type I', ,'Type II')
errorbar(texp_Fiber_CON_1-5, Cexp_Fiber_CON_1(:,2),...
                             Cexp_Fiber_ErrorL_CON_1(:,2), ...
                             Cexp_Fiber_ErrorU_CON_1(:,2),...
         'kd', 'MarkerFaceColor','k', 'MarkerSize',size1, 'LineWidth',size2)
xlabel('Time, t [min]', 'FontName','Times New Roman', 'FontSize',11,'FontWeight','bold');
title('Glycogen in Fibers', 'FontName','Times New Roman', 'FontSize',12,'FontWeight','bold')
ylabel('mmol/(kg dw)', 'FontName','Times New Roman', 'FontSize',11,'FontWeight','bold');
%set(gca,'XtickLabel',[])
axis([-6 Tend-6 100 350]);
%axis 'autoy'
set(gca, 'LineWidth',2, 'FontName','Times New Roman', 'FontSize',10);
set(gca, 'XTick', [-5,0:5:20]);
set(gca, 'YTick', [100.:100:350]);
text(-4,335, 'F','FontSize',15,'FontWeight','bold')
%--------------------------------------------------------------------------
subplot(3,3,8); subplot('position',[0.38 0.06 0.28 0.26]);   % ATP
plot(t-6, (Cc_mat_R(:,22)*V_cyt_R + Cm_mat_R(:,7)*V_mit_R)/...
          (Cc_mat_R(1,22)*V_cyt_R + Cm_mat_R(1,7)*V_mit_R)*Cexp_Fiber_CON_1(1,3),...
           type1,'LineWidth',3);
hold on
errorbar(texp_Fiber_CON_1-5, Cexp_Fiber_CON_1(:,3), ...
                             Cexp_Fiber_ErrorL_CON_1(:,3), ...
                             Cexp_Fiber_ErrorU_CON_1(:,3),...
         'k^', 'MarkerFaceColor','k','MarkerSize',size1, 'LineWidth',size2)
hold on
plot(t-6, (Cc_mat_W(:,22)*V_cyt_W + Cm_mat_W(:,7)*V_mit_W)/...
          (Cc_mat_W(1,22)*V_cyt_W + Cm_mat_W(1,7)*V_mit_W)*Cexp_Fiber_CON_1(1,4),...
          type2,'LineWidth',3);

hold on 
errorbar(texp_Fiber_CON_1-5, Cexp_Fiber_CON_1(:,4), ...
                             Cexp_Fiber_ErrorL_CON_1(:,4), ...
                             Cexp_Fiber_ErrorU_CON_1(:,4),...
         'kd', 'MarkerFaceColor','k','MarkerSize',size1, 'LineWidth',size2)
xlabel('Time, t [min]', 'FontName','Times New Roman', 'FontSize',11,'FontWeight','bold');
title('ATP in Fibers ', 'FontName','Times New Roman', 'FontSize',12,'FontWeight','bold')
%ylabel('', 'FontName','Times New Roman', 'FontSize',10);
%set(gca,'XtickLabel',[])
axis([-6 Tend-6 15 25]);
%axis 'autoy'
set(gca, 'LineWidth',2, 'FontName','Times New Roman', 'FontSize',10);
set(gca, 'XTick', [-5,0:5:20]);
set(gca, 'YTick', [15:5:25]);
text(-4,24.4, 'G','FontSize',15,'FontWeight','bold')
%--------------------------------------------------------------------------
subplot(3,3,9); subplot('position',[0.71 0.06 0.28 0.26]);       % PCr 
plot(t-6, Cc_mat_R(:,20)/Cc_mat_R(1,20)*Cexp_Fiber_CON_1(1,5),type1,'LineWidth',3);
hold on
errorbar(texp_Fiber_CON_1-5, Cexp_Fiber_CON_1(:,5), ...
                             Cexp_Fiber_ErrorL_CON_1(:,5), ...
                             Cexp_Fiber_ErrorU_CON_1(:,5),...
         'k^', 'MarkerFaceColor','k', 'MarkerSize',size1, 'LineWidth',size2)
hold on
plot(t-6, Cc_mat_W(:,20)/Cc_mat_W(1,20)*Cexp_Fiber_CON_1(1,6),type2,'LineWidth',3);

hold on 
errorbar(texp_Fiber_CON_1-5, Cexp_Fiber_CON_1(:,6),...
                             Cexp_Fiber_ErrorL_CON_1(:,6), ...
                             Cexp_Fiber_ErrorU_CON_1(:,6), ...
         'kd', 'MarkerFaceColor','k','MarkerSize',size1, 'LineWidth',size2)
xlabel('Time, t [min]', 'FontName','Times New Roman', 'FontSize',11,'FontWeight','bold');
title('PCr in Fibers', 'FontName','Times New Roman', 'FontSize',12,'FontWeight','bold')
ylabel('', 'FontName','Times New Roman', 'FontSize',10);
axis([-6 Tend-6 20 90]);
%axis 'autoy'
set(gca, 'LineWidth',2, 'FontName','Times New Roman', 'FontSize',10);
set(gca, 'XTick', [-5,0:5:20]);
set(gca, 'YTick', [20:20:100]);
text(-4,85, 'H','FontSize',15,'FontWeight','bold')
%==========================================================================
% VO2
% The effect of volume should be considered 
VO2_t =((Rflux_mat_R(:,28) + Rflux_mat_R(:,29)).*V_R_ex +...
       +(Rflux_mat_W(:,28) + Rflux_mat_W(:,29)).*V_W_ex)... 
        /2/2;
VO2_0 =(Rflux_mat_R(1,28) + Rflux_mat_R(1,29)+...
        Rflux_mat_W(1,28) + Rflux_mat_W(1,29))/2;
figure(2)                                                               
set(figure(2),'Units','inches','Position',[2 3 7 6])
plot(t-6, (VO2_t*0.0224-VO2_0*0.0224)*2,'r-','LineWidth',3);
xlabel('Time, t [min]', 'FontName','Times New Roman', 'FontSize',10);
title('Increase of Oxygen consumption', 'FontName','Times New Roman', 'FontSize',12,'FontWeight','bold')
ylabel('l/min', 'FontName','Times New Roman', 'FontSize',10);
axis([-6 Tend-6 0 2]);
%axis 'autoy'
set(gca, 'LineWidth',2, 'FontName','Times New Roman', 'FontSize',10);
set(gca, 'XTick', [-5,0:5:20]);
set(gca, 'YTick', [0:0.2:2]);

%==========================================================================
%% Simulate the MOD 3 condition 
%---------------------------------------------------------------
WR_Unload = 25;                          % Work rate for unloaded pedalling
WR_Cycle  = 125;                         % Work rate load on cycle ergometer for moderate intensity exercise (Approx. 60% VO2 max)
WR_Exer   = WR_Unload + WR_Cycle;        % Total work rate for exercise
%---------------------------------------------------------------
Alpha_t_R(3)=Alpha_t_R(3)*0.25;           %0.3

[t,C] = ode15s(@SkelMusMet_Cdot,Tspan,C0,options, WR_Exer);

%*************************************************************************
%              This section sets for the model output 
%*************************************************************************
% 1 Define the vectors to record the dynamic values  
%==========================================================================
Q_vec =[];                               % Blood flow
V_ex  =[] ;                              % Muscle volume in exercise
Ca_mat =[];                              % Species in arterial 
Cb_mat = [];                             % Species in blood
V_R_ex =[];
V_W_ex =[];
V_BISF_ex =[]; 
%-----------------------------Fluxes--------------------------------------- 
URR_mat_R = [];                          % Uptake/Release for Type I 
Rflux_mat_R = [];                        % Reaction fluxes for Type I
Cc_mat_R = [];                           % Species in cytosol in Type I   
Cm_mat_R = [];                           % Species in mitochondria in Type I   
URR_mat_W = [];                         % Uptake/Release for Type II  
Rflux_mat_W = [];                       % Reaction fluxes for Type II
Cc_mat_W = [];                          % Species in cytosol in Type II  
Cm_mat_W = [];                          % Species in mitochondria in Type II
%==========================================================================
% 2   Write the dynamic variables data into these vectors during simulation  
%==========================================================================
for j = 1:Nstep+1
    tj = t(j);
    Cj = C(j,:)';
    [Cdotj] = SkelMusMet_Cdot(tj,Cj,WR_Exer);

    Q_vec  = [Q_vec; Q];
    V_R_ex =[V_R_ex; V_R_active];
    V_W_ex =[V_W_ex; V_W_active];    
    V_ex  = [V_ex; V_mus_active];
    V_BISF_ex=[V_BISF_ex; V_BISF_active];
    
    Ca_mat = [Ca_mat;Ca(1:9)'];                     %arterial species    
    Cb_mat = [Cb_mat; Cj(1:9)']; 
%==========================================================================
%                                   Type I
%==========================================================================
    URR_mat_R = [URR_mat_R;[URR_R(1:8)',URR_R(29),URR_R(30:40)']];
    Rflux_mat_R = [Rflux_mat_R;Rflux_R'];

    Cc_mat_R = [Cc_mat_R;Cj(10:38)'];                 %cytosol species
    Cm_mat_R = [Cm_mat_R;Cj(39:59)'];                 %mitochondria species

%==========================================================================
%                                Type II
%==========================================================================
    URR_mat_W = [URR_mat_W; [URR_W(1:8)',URR_W(29), URR_W(30:40)']];
    Rflux_mat_W = [Rflux_mat_W; Rflux_W'];
    Cc_mat_W = [Cc_mat_W; Cj(60:88)'];
    Cm_mat_W = [Cm_mat_W; Cj(89:109)'];
end
%%

figure(11)                                                               
set(figure(11),'Units','inches','Position',[2 2 10 8])
%--------------------------------------------------------------------------
subplot(3,3,1); subplot('position',[0.05 0.71 0.28 0.26]);   % Glucose 
plot(t-6, (Cc_mat_R(:,1)*V_cyt_R + Cc_mat_W(:,1)*V_cyt_W)/...
          (Cc0_R(1)*V_cyt_R + Cc0_W(1) *V_cyt_W)*Cexp_Tis_CON_3a(1,1), ...
           type_t,'LineWidth',3);
% hold on
% plot(t-6, (Cc_mat_R(:,1))/(Cc0_R(1)), type1,'LineWidth',3);
% hold on 
% plot(t-6, (Cc_mat_W(:,1))/(Cc0_W(1)), type2,'LineWidth',3);
% hold on
%xlabel('Time, t [min]', 'FontName','Times New Roman', 'FontSize',10);
title('Tissue Glucose', 'FontName','Times New Roman', 'FontSize',12,'FontWeight','bold')
ylabel('mmoll/(kg dw)', 'FontName','Times New Roman', 'FontSize',11,'FontWeight','bold');
axis([-6 Tend-6 0. 15]);
%axis 'autoy'
set(gca, 'LineWidth',2, 'FontName','Times New Roman', 'FontSize',10);
set(gca, 'XTick', [-5,0:5:20]);
set(gca, 'YTick', [0.:5:15]);
set(gca,'XtickLabel',[])
hold on
errorbar(texp_Tis_CON_3a -5, Cexp_Tis_CON_3a(:,1),...
                             Cexp_Tis_ErrorL_CON_3a (:,1), ...
                             Cexp_Tis_ErrorU_CON_3a (:,1),...
                             'ks', 'MarkerFaceColor','k', 'MarkerSize',size1, 'LineWidth',size2)
text(-4,14, 'A','FontSize',15,'FontWeight','bold')
hold on
%--------------------------------------------------------------------------
subplot(3,3,2); subplot('position',[0.38 0.71 0.28 0.26]);   % Glycogen 
plot(t-6,((Cc_mat_R(:,11)*V_cyt_R + Cc_mat_W(:,11)*V_cyt_W)/...
         (Cc0_R(11)*V_cyt_R + Cc0_W(11) *V_cyt_W)).^1. ...
         *Cexp_Tis_CON_3b (1,1), ...
      type_t,'LineWidth',3)
% hold on 
% plot(t-6,(Cc_mat_R(:,11))/(Cc0_R(11))*200,type1,'LineWidth',3)
% hold on 
% plot(t-6,(Cc_mat_W(:,11))/(Cc0_W(11))*200,type2,'LineWidth',3)
% hold on
%xlabel('Time, t [min]', 'FontName','Times New Roman', 'FontSize',10);
title('Tissue Glycogen', 'FontName','Times New Roman', 'FontSize',12,'Fontweight','bold');
%ylabel('C(t)/C(0)', 'FontName','Times New Roman', 'FontSize',10)
axis([-6 Tend-6 0. 600]);
%axis 'autoy'
set(gca, 'LineWidth',2, 'FontName','Times New Roman', 'FontSize',10);
set(gca, 'XTick', [-5,0:5:20]);
set(gca, 'YTick', [0:200:600]);
set(gca,'XtickLabel',[])
hold on
errorbar(texp_Tis_CON_3b-5, Cexp_Tis_CON_3b (:,1),...
                            Cexp_Tis_ErrorL_CON_3b (:,1), ...
                            Cexp_Tis_ErrorU_CON_3b (:,1),...
         'ks', 'MarkerFaceColor','k', 'MarkerSize',size1, 'LineWidth',size2)
text(-4,560, 'B','FontSize',15,'FontWeight','bold')
%--------------------------------------------------------------------------
subplot(3,3,3); subplot('position',[0.71 0.71 0.28 0.26]);   % G6P 
plot(t-6,(Cc_mat_R(:,9)*V_cyt_R + Cc_mat_W(:,9)*V_cyt_W)/...
         (Cc0_R(9)*V_cyt_R + Cc0_W(9) *V_cyt_W)*Cexp_Tis_CON_3a (1,2), ...
      type_t,'LineWidth',3)
% hold on 
% plot(t-6,(Cc_mat_R(:,9))/(Cc0_R(9)),type1,'LineWidth',3)
% hold on 
% plot(t-6,(Cc_mat_W(:,9))/(Cc0_W(9)),type2,'LineWidth',3)
% hold on  
%xlabel('Time, t [min]', 'FontName','Times New Roman', 'FontSize',10);
title('Tissue G6P', 'FontName','Times New Roman', 'FontSize',12,'Fontweight','bold');
%ylabel('C(t)/C(0)', 'FontName','Times New Roman',  'FontSize',10)
axis([-6 Tend-6 0. 5]);
%axis 'autoy'
set(gca, 'LineWidth',2, 'FontName','Times New Roman', 'FontSize',10);
set(gca, 'XTick', [-5,0:5:20]);
set(gca, 'YTick', [0.:1:5]);
set(gca,'XtickLabel',[])
hold on
errorbar(texp_Tis_CON_3a-5, Cexp_Tis_CON_3a (:,2),...
                            Cexp_Tis_ErrorL_CON_3a(:,2), ...
                            Cexp_Tis_ErrorU_CON_3a(:,2),...
         'ks', 'MarkerFaceColor','k','MarkerSize',size1, 'LineWidth',size2)
text(-4,4.7, 'C','FontSize',15,'FontWeight','bold')

%--------------------------------------------------------------------------
subplot(3,3,4); subplot('position',[0.05 0.39 0.28 0.26]);   % F6P 
plot(t-6,((Cc_mat_R(:,12)*V_cyt_R + Cc_mat_W(:,12)*V_cyt_W)/...
         (Cc0_R(12)*V_cyt_R + Cc0_W(12) *V_cyt_W)).^0.95 ...
         *Cexp_Tis_CON_3a (1,3)...
           ,type_t,'LineWidth',3)
% hold on 
% plot(t-6,(Cc_mat_R(:,12))/(Cc0_R(12))/10,type1,'LineWidth',3)
% hold on 
% plot(t-6,(Cc_mat_W(:,12))/(Cc0_W(12))/10,type2,'LineWidth',3)
% hold on  
       
%xlabel('Time, t [min]', 'FontName','Times New Roman', 'FontSize',10);
title('Tissue F6P', 'FontName','Times New Roman', 'FontSize',12,'Fontweight','bold');
ylabel('mmoll/(kg dw)', 'FontName','Times New Roman', ...
       'FontSize',11,'Fontweight','bold')
axis([-6 Tend-6 0.0 0.8]);
%axis 'autoy'
set(gca, 'LineWidth',2, 'FontName','Times New Roman', 'FontSize',10);
%set(gca, 'XTick', [-5,0:0.1:1]);
set(gca, 'YTick', [0.0:0.2:0.8]);
hold on
errorbar(texp_Tis_CON_3a-5, Cexp_Tis_CON_3a (:,3),...
                            Cexp_Tis_ErrorL_CON_3a(:,3), ...
                            Cexp_Tis_ErrorU_CON_3a(:,3),...
         'ks', 'MarkerFaceColor','k','MarkerSize',size1, 'LineWidth',size2)
text(-4,0.75, 'D','FontSize',15,'FontWeight','bold')

set(gca,'XtickLabel',[])
%--------------------------------------------------------------------------
subplot(3,3,5); subplot('position',[0.38 0.39 0.28 0.26]);   % Pyr
plot(t-6, ...
     (Cc_mat_R(:,2)*V_cyt_R + Cm_mat_R(:,3)*V_mit_R+ Cc_mat_W(:,2)*V_cyt_W + Cm_mat_W(:,3)*V_mit_W)/...
     (Cc0_R(2)*V_cyt_R + Cc0_R(32)*V_mit_R +  Cc0_W(2)*V_cyt_W + Cc0_W(32)*V_mit_W)*Cexp_Tis_CON_3a (1,4),...
     type_t,'LineWidth',3)
% hold on
% plot(t-6, ...
%      (Cc_mat_R(:,2)*V_cyt_R + Cm_mat_R(:,3)*V_mit_R )/...
%      (Cc0_R(2)*V_cyt_R + Cc0_R(32)*V_mit_R)/10,type1,'LineWidth',3)
% hold on 
% plot(t-6, ...
%      (Cc_mat_W(:,2)*V_cyt_W + Cm_mat_W(:,3)*V_mit_W )/...
%      (Cc0_W(2)*V_cyt_W + Cc0_W(32)*V_mit_W)/10,type2,'LineWidth',3)
% hold on
%xlabel('Time, t [min]', 'FontName','Times New Roman', 'FontSize',10);
title('Tissue Pyruvate', 'FontName','Times New Roman', 'FontSize',12,'Fontweight','bold');
%ylabel('C(t)/C(0)', 'FontName','Times New Roman', 'FontSize',10)
%ylabel('C_{Pyr}(t) in cell [mmol/kg ww]', 'FontName','Times New Roman', 'FontSize',10);
axis([-6 Tend-6 0.0 0.75]);
%axis 'autoy'
set(gca, 'LineWidth',2, 'FontName','Times New Roman', 'FontSize',10);
set(gca, 'XTick', [-5,0:5:15]);
set(gca, 'YTick', [0.0:0.2:0.75]);
hold on
errorbar(texp_Tis_CON_3a-5, Cexp_Tis_CON_3a (:,4),...
                            Cexp_Tis_ErrorL_CON_3a(:,4),...
                            Cexp_Tis_ErrorU_CON_3a(:,4), ...
         'ks', 'MarkerFaceColor','k', 'MarkerSize',size1, 'LineWidth',size2)
text(-4,0.7, 'E','FontSize',15,'FontWeight','bold')
set(gca,'XtickLabel',[])
%--------------------------------------------------------------------------
subplot(3,3,6); subplot('position',[0.71 0.39 0.28 0.26]);   % Lac
plot(t-6,(Cc_mat_R(:,3)*V_cyt_R + Cc_mat_W(:,3)*V_cyt_W)/...
         (Cc0_R(3)*V_cyt_R + Cc0_W(3) *V_cyt_W)*Cexp_Tis_CON_3a (1,5),...
     type_t,'LineWidth',3)
% hold on
% plot(t-6,(Cc_mat_R(:,3)*V_cyt_R )/(Cc0_R(3)*V_cyt_R ),type1,'LineWidth',3)
% hold on
% plot(t-6,(Cc_mat_W(:,3)*V_cyt_W)/(Cc0_W(3) *V_cyt_W),type2,'LineWidth',3)
% hold on
%xlabel('Time, t [min]', 'FontName','Times New Roman', 'FontSize',10);
title('Tissue Lactate', 'FontName','Times New Roman', 'FontSize',12,'Fontweight','bold');
%ylabel('C(t)/C(0)', 'FontName','Times New Roman', 'FontSize',10)
axis([-6 Tend-6 0. 25]);
%axis 'autoy'
set(gca, 'LineWidth',2, 'FontName','Times New Roman', 'FontSize',10);
set(gca, 'XTick', [-5,0:5:15]);
set(gca, 'YTick', [0.:5:25]);
set(gca,'XtickLabel',[])
hold on
errorbar(texp_Tis_CON_3a-5, Cexp_Tis_CON_3a (:,5), ...
                            Cexp_Tis_ErrorL_CON_3a(:,5),...
                            Cexp_Tis_ErrorU_CON_3a(:,5),...
         'ks', 'MarkerFaceColor','k', 'MarkerSize',size1, 'LineWidth',size2)
text(-4,23.5, 'F','FontSize',15,'FontWeight','bold')
%--------------------------------------------------------------------------
subplot(3,3,7); subplot('position',[0.05 0.06 0.28 0.26]);   % PCr Cr 
plot(t-6,((Cc_mat_R(:,20)*V_cyt_R + Cc_mat_W(:,20)*V_cyt_W)/...
         (Cc0_R(20)*V_cyt_R + Cc0_W(20) *V_cyt_W)).^1.1*Cexp_Tis_CON_3b(1,3) ,...
         type_t,'LineWidth',3)
hold on 
plot(t-6,(Cc_mat_R(:,21)*V_cyt_R + Cc_mat_W(:,21)*V_cyt_W)/...
         (Cc0_R(21)*V_cyt_R + Cc0_W(21) *V_cyt_W)*Cexp_Tis_CON_3b (1,4)/2,...
         type_t,'LineWidth',3)
% hold on
% plot(t-6,(Cc_mat_R(:,20)*V_cyt_R )/(Cc0_R(20)*V_cyt_R)*20,type1,'LineWidth',3)
% hold on
% plot(t-6,(Cc_mat_W(:,20)*V_cyt_W)/(Cc0_W(20) *V_cyt_W)*20,type2,'LineWidth',3)
% hold on
% plot(t-6,(Cc_mat_R(:,21)*V_cyt_R )/(Cc0_R(21)*V_cyt_R)*20,type1,'LineWidth',3)
% hold on
% plot(t-6,(Cc_mat_W(:,21)*V_cyt_W)/(Cc0_W(21) *V_cyt_W)*20,type2,'LineWidth',3)
% hold on
% text(5,1.58,'Cr','Fontweight','bold','FontName','Times New Roman', 'FontSize',10)
% text(5,0.6,'PCr','Fontweight','bold','FontName','Times New Roman', 'FontSize',10)
%^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
% x=[0.15 0.18 ]; y=[0.28 0.26];
% txtar =  annotation('textarrow',x,y,'String','Cr','FontSize',10,'FontWeight','bold');
% x=[0.15 0.18 ]; y=[0.28 0.23];
% txtar =  annotation('textarrow',x,y);
% %^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
% x=[0.15 0.18 ]; y=[0.12 0.16];
% txtar =  annotation('textarrow',x,y,'String','PCr','FontSize',10,'FontWeight','bold');
% x=[0.15 0.18 ]; y=[0.12 0.18];
% txtar =  annotation('textarrow',x,y);
%^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
%xlabel('Time, t [min]', 'FontName','Times New Roman', 'FontSize',11,'Fontweight','bold');
title('Tissue PCr and Cr', 'FontName','Times New Roman', 'FontSize',12,'Fontweight','bold');
ylabel('mmoll/(kg dw)', 'FontName','Times New Roman', ...
      'FontSize',11,'Fontweight','bold')
%axis([-6 Tend-6 0 1.2]);
%axis 'autoy'
set(gca, 'LineWidth',2, 'FontName','Times New Roman', 'FontSize',10);
set(gca, 'XTick', [-5,0:5:20]);
%set(gca, 'YTick', [0:0.25:1.2]);
hold on
errorbar(texp_Tis_CON_3b-5, Cexp_Tis_CON_3b (:,3),...
               Cexp_Tis_ErrorL_CON_3b (:,3), ...
               Cexp_Tis_ErrorU_CON_3b (:,3), ...
               'kd', 'MarkerFaceColor','k', 'MarkerSize',size1, ...
    'LineWidth',size2)

xlabel('Time [min]', 'FontName','Times New Roman', 'FontSize',11,'Fontweight','bold');
axis([-6 Tend-6 0 100]);
%axis 'autoy'
set(gca, 'LineWidth',2, 'FontName','Times New Roman', 'FontSize',10);
set(gca, 'XTick', [-5,0:5:20]);
set(gca, 'YTick', [0:20:100]);
hold on
errorbar(texp_Tis_CON_3b-5, Cexp_Tis_CON_3b(:,4)/2, ...
              Cexp_Tis_ErrorL_CON_3b (:,4)/2, ...
              Cexp_Tis_ErrorU_CON_3b (:,4)/2, ...
              'ks', 'MarkerFaceColor','k', 'MarkerSize',8, ...
    'LineWidth',3)
text(-4,94,'G','FontSize',15,'FontWeight','bold')
% legend('PCr','Cr','location','southeast')
% legend('boxoff')
text(5,78,'PCr','FontSize',13)
text(5,35,'Cr/2','FontSize',13)
%--------------------------------------------------------------------------
subplot(3,3,8); subplot('position',[0.38 0.06 0.28 0.26]);   % ATP
plot(t-6,...
     (Cc_mat_R(:,22)*V_cyt_R + Cm_mat_R(:,7)*V_mit_R+ Cc_mat_W(:,22)*V_cyt_W + Cm_mat_W(:,7)*V_mit_W)/...
     (Cc0_R(22)*V_cyt_R + Cc0_R(36)*V_mit_R +  Cc0_W(22)*V_cyt_W + Cc0_W(36)*V_mit_W)*Cexp_Tis_CON_3b (1,2),...
      type_t,'LineWidth',3)
% hold on
% plot(t-6,(Cc_mat_R(:,22)*V_cyt_R + Cm_mat_R(:,7)*V_mit_R)/...
%          (Cc0_R(22)*V_cyt_R + Cc0_R(36)*V_mit_R)*20, type1,'LineWidth',3)
% hold on
% plot(t-6,(Cc_mat_W(:,22)*V_cyt_W + Cm_mat_W(:,7)*V_mit_W)/...
%          (Cc0_W(22)*V_cyt_W + Cc0_W(36)*V_mit_W)*20, type2,'LineWidth',3)
%legend('Whole tissue','Type I', 'Type II','location','southeast')     
legend('boxoff')
hold on
xlabel('Time [min]', 'FontName','Times New Roman', 'FontSize',11,'Fontweight','bold');
title('Tissue ATP', 'FontName','Times New Roman', 'FontSize',12,'Fontweight','bold');
% ylabel('C(t)/C(0)', 'FontName','Times New Roman', ...
%      'FontSize',10)
%ylabel('C_{ATP}(t) in cell [mmol/kg ww]', 'FontName','Times New Roman', 'FontSize',10);
axis([-6 Tend-6 10 30]);
%axis 'autoy'
set(gca, 'LineWidth',2, 'FontName','Times New Roman', 'FontSize',10);
set(gca, 'XTick', [-5,0:5:20]);
set(gca, 'YTick', [10:5:30]);
hold on
errorbar(texp_Tis_CON_3b-5, Cexp_Tis_CON_3b (:,2), ...
                            Cexp_Tis_ErrorL_CON_3b (:,2),...
                            Cexp_Tis_ErrorU_CON_3b (:,2)...
             , 'ks', 'MarkerFaceColor','k', 'MarkerSize',size1, 'LineWidth',size2)
text(-4,28.7,'H','FontSize',15,'FontWeight','bold')
%--------------------------------------------------------------------------
subplot(3,3,9); subplot('position',[0.71 0.06 0.28 0.26]);   % NADH/NAD
plot(t-6,...
     ((Cc_mat_R(:,27)*V_cyt_R + Cm_mat_R(:,5)*V_mit_R+ Cc_mat_W(:,27)*V_cyt_W + Cm_mat_W(:,5)*V_mit_W)./...
      (Cc_mat_R(:,28)*V_cyt_R + Cm_mat_R(:,6)*V_mit_R+ Cc_mat_W(:,28)*V_cyt_W + Cm_mat_W(:,6)*V_mit_W))/...     
     ((Cc_mat_R(1,27)*V_cyt_R + Cm_mat_R(1,5)*V_mit_R+ Cc_mat_W(1,27)*V_cyt_W + Cm_mat_W(1,5)*V_mit_W)/...
      (Cc_mat_R(1,28)*V_cyt_R + Cm_mat_R(1,6)*V_mit_R+ Cc_mat_W(1,28)*V_cyt_W + Cm_mat_W(1,6)*V_mit_W))...
      *Cexp_Tis_CON_3b(1,5)*1000 ...
      ,type_t,'LineWidth',3)
xlabel('Time [min]', 'FontName','Times New Roman', 'FontSize',10,'Fontweight','bold');
title('Tissue Redox State (NADH/NAD)', 'FontName','Times New Roman', 'FontSize',12,'Fontweight','bold');
ylabel('unitless', 'FontName','Times New Roman', 'FontSize',11,'Fontweight','bold')
axis([-6 Tend-6 0. 15]);
%axis 'autoy'
set(gca, 'LineWidth',2, 'FontName','Times New Roman', 'FontSize',10);
set(gca, 'XTick', [-5,0:5:20]);
set(gca, 'YTick', [0.:5:15]);
hold on
errorbar(texp_Tis_CON_3b-5, Cexp_Tis_CON_3b (:,5)*1000,...
                            Cexp_Tis_ErrorL_CON_3b(:,5)*1000,...
                            Cexp_Tis_ErrorU_CON_3b(:,5)*1000,...
    'ks', 'MarkerFaceColor','k','MarkerSize',size1, 'LineWidth',size2)
%text(-4, 3.6, 'D','FontSize',15)
% 
% plot(t-6,...
%      ((Cc_mat_R(:,27)*V_cyt_R + Cm_mat_R(:,5)*V_mit_R)./...
%       (Cc_mat_R(:,28)*V_cyt_R + Cm_mat_R(:,6)*V_mit_R))/...     
%      ((Cc_mat_R(1,27)*V_cyt_R + Cm_mat_R(1,5)*V_mit_R)/...
%       (Cc_mat_R(1,28)*V_cyt_R + Cm_mat_R(1,6)*V_mit_R))...
%        ,type1,'LineWidth',2.5)
% hold on     
% plot(t-6,...
%      ((Cc_mat_W(:,27)*V_cyt_W + Cm_mat_W(:,5)*V_mit_W)./...
%       (Cc_mat_W(:,28)*V_cyt_W + Cm_mat_W(:,6)*V_mit_W))/...     
%      ((Cc_mat_W(1,27)*V_cyt_W + Cm_mat_W(1,5)*V_mit_W)/...
%       (Cc_mat_W(1,28)*V_cyt_W + Cm_mat_W(1,6)*V_mit_W))... 
%       ,type2,'LineWidth',2.5)
% hold on
text(-4,14,'I','FontSize',15,'FontWeight','bold')

%==========================================================================
% VO2
VO2_t =((Rflux_mat_R(:,28) + Rflux_mat_R(:,29)).*V_R_ex +...
       +(Rflux_mat_W(:,28) + Rflux_mat_W(:,29)).*V_W_ex)... 
        /2/2;
VO2_0 =(Rflux_mat_R(1,28) + Rflux_mat_R(1,29)+...
        Rflux_mat_W(1,28) + Rflux_mat_W(1,29))/2;
   
figure(12)                                                               
set(figure(12),'Units','inches','Position',[2 3 7 6])
plot(t-6, (VO2_t*0.0224-VO2_0*0.0224)*2,'r-','LineWidth',3);
xlabel('Time, t [min]', 'FontName','Times New Roman', 'FontSize',10);
title('Increase of Oxygen consumption', 'FontName','Times New Roman', 'FontSize',12,'FontWeight','bold')
ylabel('l/min', 'FontName','Times New Roman', 'FontSize',10);
axis([-6 Tend-6 0 2]);
%axis 'autoy'
set(gca, 'LineWidth',2, 'FontName','Times New Roman', 'FontSize',10);
set(gca, 'XTick', [-5,0:5:20]);
set(gca, 'YTick', [0:0.2:2]);
%%
%==========================================================================
figure(13)                                                               
set(figure(13),'Units','inches','Position',[2 2 10 8])
%--------------------------------------------------------------------------
subplot(3,3,1); subplot('position',[0.05 0.71 0.28 0.26]);   % Glucose 
% plot(t-6, (Cc_mat_R(:,1)*V_cyt_R + Cc_mat_W(:,1)*V_cyt_W)/...
%           (Cc0_R(1)*V_cyt_R + Cc0_W(1) *V_cyt_W)*Cexp_Tis_CON_3a(1,1), ...
%            type_t,'LineWidth',3);
% hold on
plot(t-6, (Cc_mat_R(:,1))/(Cc0_R(1)), type1,'LineWidth',3);
hold on 
plot(t-6, (Cc_mat_W(:,1))/(Cc0_W(1)), type2,'LineWidth',3);
hold on
%xlabel('Time, t [min]', 'FontName','Times New Roman', 'FontSize',10);
title('Glucose', 'FontName','Times New Roman', 'FontSize',12,'FontWeight','bold')
ylabel('unitless', 'FontName','Times New Roman', 'FontSize',11,'FontWeight','bold');
axis([-6 Tend-6 0. 5]);
%axis 'autoy'
set(gca, 'LineWidth',2, 'FontName','Times New Roman', 'FontSize',10);
set(gca, 'XTick', [-5,0:5:20]);
set(gca, 'YTick', [0.:1:5]);
set(gca,'XtickLabel',[])
% hold on
% errorbar(texp_Tis_CON_3a -5, Cexp_Tis_CON_3a(:,1),...
%                              Cexp_Tis_ErrorL_CON_3a (:,1), ...
%                              Cexp_Tis_ErrorU_CON_3a (:,1),...
%                              'ks', 'MarkerFaceColor','k', 'MarkerSize',8, 'LineWidth',2.5)
text(-4,4.65, 'A','FontSize',15,'FontWeight','bold')
hold on
%--------------------------------------------------------------------------
subplot(3,3,2); subplot('position',[0.38 0.71 0.28 0.26]);   % Glycogen 
% plot(t-6,((Cc_mat_R(:,11)*V_cyt_R + Cc_mat_W(:,11)*V_cyt_W)/...
%          (Cc0_R(11)*V_cyt_R + Cc0_W(11) *V_cyt_W)).^1.2 ...
%          *Cexp_Tis_CON_3b (1,1), ...
%       type_t,'LineWidth',3)
% hold on 
plot(t-6,(Cc_mat_R(:,11)/Cc0_R(11)).^1.2,type1,'LineWidth',3)
hold on 
plot(t-6,(Cc_mat_W(:,11))/(Cc0_W(11)),type2,'LineWidth',3)
hold on
%xlabel('Time, t [min]', 'FontName','Times New Roman', 'FontSize',10);
title('Glycogen', 'FontName','Times New Roman', 'FontSize',12,'Fontweight','bold');
%ylabel('C(t)/C(0)', 'FontName','Times New Roman', 'FontSize',10)
axis([-6 Tend-6 0.5 1.3]);
%axis 'autoy'
set(gca, 'LineWidth',2, 'FontName','Times New Roman', 'FontSize',10);
set(gca, 'XTick', [-5,0:5:20]);
set(gca, 'YTick', [0:0.5:1.3]);
set(gca,'XtickLabel',[])
% hold on
% errorbar(texp_Tis_CON_3b-5, Cexp_Tis_CON_3b (:,1),...
%                             Cexp_Tis_ErrorL_CON_3b (:,1), ...
%                             Cexp_Tis_ErrorU_CON_3b (:,1),...
%          'ks', 'MarkerFaceColor','k', 'MarkerSize',8, 'LineWidth',2.5)
text(-4,1.25, 'B','FontSize',15,'FontWeight','bold')
%--------------------------------------------------------------------------
subplot(3,3,3); subplot('position',[0.71 0.71 0.28 0.26]);   % G6P 
% plot(t-6,(Cc_mat_R(:,9)*V_cyt_R + Cc_mat_W(:,9)*V_cyt_W)/...
%          (Cc0_R(9)*V_cyt_R + Cc0_W(9) *V_cyt_W)*Cexp_Tis_CON_3a (1,2), ...
%       type_t,'LineWidth',3)
% hold on 
plot(t-6,(Cc_mat_R(:,9))/(Cc0_R(9)),type1,'LineWidth',3)
hold on 
plot(t-6,(Cc_mat_W(:,9))/(Cc0_W(9)),type2,'LineWidth',3)
hold on  
%xlabel('Time, t [min]', 'FontName','Times New Roman', 'FontSize',10);
title('G6P', 'FontName','Times New Roman', 'FontSize',12,'Fontweight','bold');
%ylabel('C(t)/C(0)', 'FontName','Times New Roman',  'FontSize',10)
axis([-6 Tend-6 0 5]);
%axis 'autoy'
set(gca, 'LineWidth',2, 'FontName','Times New Roman', 'FontSize',10);
set(gca, 'XTick', [-5,0:5:20]);
set(gca, 'YTick', [0.:1:5]);
set(gca,'XtickLabel',[])
% hold on
% errorbar(texp_Tis_CON_3a-5, Cexp_Tis_CON_3a (:,2),...
%                             Cexp_Tis_ErrorL_CON_3a(:,2), ...
%                             Cexp_Tis_ErrorU_CON_3a(:,2),...
%          'ks', 'MarkerFaceColor','k', 'MarkerSize',8,'LineWidth',2.5)
text(-4,4.65, 'C','FontSize',15,'FontWeight','bold')

%--------------------------------------------------------------------------
subplot(3,3,4); subplot('position',[0.05 0.39 0.28 0.26]);   % F6P 
% plot(t-6,((Cc_mat_R(:,12)*V_cyt_R + Cc_mat_W(:,12)*V_cyt_W)/...
%          (Cc0_R(12)*V_cyt_R + Cc0_W(12) *V_cyt_W)).^0.8...
%          *Cexp_Tis_CON_3a (1,3)...
%            ,type_t,'LineWidth',3)
% hold on 
plot(t-6,((Cc_mat_R(:,12))/(Cc0_R(12))).^0.95,type1,'LineWidth',3)
hold on 
plot(t-6,(Cc_mat_W(:,12))/(Cc0_W(12)),type2,'LineWidth',3)
hold on  
       
%xlabel('Time, t [min]', 'FontName','Times New Roman', 'FontSize',10);
title('F6P', 'FontName','Times New Roman', 'FontSize',12,'Fontweight','bold');
ylabel('unitless', 'FontName','Times New Roman', ...
       'FontSize',11,'Fontweight','bold')
axis([-6 Tend-6 0.0 5]);
%axis 'autoy'
set(gca, 'LineWidth',2, 'FontName','Times New Roman', 'FontSize',10);
%set(gca, 'XTick', [-5,0:0.1:1]);
set(gca, 'YTick', [0.0:1:5]);
hold on
% errorbar(texp_Tis_CON_3a-5, Cexp_Tis_CON_3a (:,3),...
%                             Cexp_Tis_ErrorL_CON_3a(:,3), ...
%                             Cexp_Tis_ErrorU_CON_3a(:,3),...
%          'ks', 'MarkerFaceColor','k', 'MarkerSize',8, 'LineWidth',2.5)
text(-4,4.6, 'D','FontSize',15,'FontWeight','bold')

set(gca,'XtickLabel',[])
%--------------------------------------------------------------------------
subplot(3,3,5); subplot('position',[0.38 0.39 0.28 0.26]);   % Pyr
% plot(t-6, ...
%      (Cc_mat_R(:,2)*V_cyt_R + Cm_mat_R(:,3)*V_mit_R+ Cc_mat_W(:,2)*V_cyt_W + Cm_mat_W(:,3)*V_mit_W)/...
%      (Cc0_R(2)*V_cyt_R + Cc0_R(32)*V_mit_R +  Cc0_W(2)*V_cyt_W + Cc0_W(32)*V_mit_W)*Cexp_Tis_CON_3a (1,4),...
%      type_t,'LineWidth',3)
% hold on
plot(t-6, ...
     (Cc_mat_R(:,2)*V_cyt_R + Cm_mat_R(:,3)*V_mit_R )/...
     (Cc0_R(2)*V_cyt_R + Cc0_R(32)*V_mit_R),type1,'LineWidth',3)
hold on 
plot(t-6, ...
     (Cc_mat_W(:,2)*V_cyt_W + Cm_mat_W(:,3)*V_mit_W )/...
     (Cc0_W(2)*V_cyt_W + Cc0_W(32)*V_mit_W),type2,'LineWidth',3)
hold on
%xlabel('Time, t [min]', 'FontName','Times New Roman', 'FontSize',10);
title('Pyruvate', 'FontName','Times New Roman', 'FontSize',12,'Fontweight','bold');
%ylabel('C(t)/C(0)', 'FontName','Times New Roman', 'FontSize',10)
%ylabel('C_{Pyr}(t) in cell [mmol/kg ww]', 'FontName','Times New Roman', 'FontSize',10);
axis([-6 Tend-6 0.0 3]);
%axis 'autoy'
set(gca, 'LineWidth',2, 'FontName','Times New Roman', 'FontSize',10);
set(gca, 'XTick', [-5,0:5:15]);
set(gca, 'YTick', [0.0:1:3]);
hold on
% errorbar(texp_Tis_CON_3a-5, Cexp_Tis_CON_3a (:,4),...
%                             Cexp_Tis_ErrorL_CON_3a(:,4),...
%                             Cexp_Tis_ErrorU_CON_3a(:,4), ...
%          'ks', 'MarkerFaceColor','k', 'MarkerSize',8, 'LineWidth',2.5)
text(-4,2.8, 'E','FontSize',15,'FontWeight','bold')
set(gca,'XtickLabel',[])
%--------------------------------------------------------------------------
subplot(3,3,6); subplot('position',[0.71 0.39 0.28 0.26]);   % Lac
% plot(t-6,(Cc_mat_R(:,3)*V_cyt_R + Cc_mat_W(:,3)*V_cyt_W)/...
%          (Cc0_R(3)*V_cyt_R + Cc0_W(3) *V_cyt_W)*Cexp_Tis_CON_3a (1,5),...
%      type_t,'LineWidth',3)
% hold on
plot(t-6,(Cc_mat_R(:,3)*V_cyt_R )/(Cc0_R(3)*V_cyt_R ),type1,'LineWidth',3)
hold on
plot(t-6,(Cc_mat_W(:,3)*V_cyt_W)/(Cc0_W(3) *V_cyt_W),type2,'LineWidth',3)
hold on
%xlabel('Time, t [min]', 'FontName','Times New Roman', 'FontSize',10);
title('Lactate', 'FontName','Times New Roman', 'FontSize',12,'Fontweight','bold');
%ylabel('C(t)/C(0)', 'FontName','Times New Roman', 'FontSize',10)
axis([-6 Tend-6 0. 6]);
%axis 'autoy'
set(gca, 'LineWidth',2, 'FontName','Times New Roman', 'FontSize',10);
set(gca, 'XTick', [-5,0:5:15]);
set(gca, 'YTick', [0.:1:6]);
set(gca,'XtickLabel',[])
hold on
% errorbar(texp_Tis_CON_3a-5, Cexp_Tis_CON_3a (:,5), ...
%                             Cexp_Tis_ErrorL_CON_3a(:,5),...
%                             Cexp_Tis_ErrorU_CON_3a(:,5),...
%          'ks', 'MarkerFaceColor','k', 'MarkerSize',8, 'LineWidth',2.5)
text(-4,5.6, 'F','FontSize',15,'FontWeight','bold')
%--------------------------------------------------------------------------
subplot(3,3,7); subplot('position',[0.05 0.06 0.28 0.26]);   % PCr Cr 
% plot(t-6,(Cc_mat_R(:,20)*V_cyt_R + Cc_mat_W(:,20)*V_cyt_W)/...
%          (Cc0_R(20)*V_cyt_R + Cc0_W(20) *V_cyt_W)*Cexp_Tis_CON_3b (1,3),...
%          type_t,'LineWidth',3)
% hold on 
% plot(t-6,(Cc_mat_R(:,21)*V_cyt_R + Cc_mat_W(:,21)*V_cyt_W)/...
%          (Cc0_R(21)*V_cyt_R + Cc0_W(21) *V_cyt_W)*Cexp_Tis_CON_3b (1,4)/2,...
%          type_t,'LineWidth',3)
% hold on
plot(t-6,(Cc_mat_R(:,20)*V_cyt_R )/(Cc0_R(20)*V_cyt_R),type1,'LineWidth',3)
hold on
plot(t-6,(Cc_mat_W(:,20)*V_cyt_W)/(Cc0_W(20) *V_cyt_W),type2,'LineWidth',3)
hold on
plot(t-6,(Cc_mat_R(:,21)*V_cyt_R )/(Cc0_R(21)*V_cyt_R),type1,'LineWidth',3)
hold on
plot(t-6,(Cc_mat_W(:,21)*V_cyt_W)/(Cc0_W(21) *V_cyt_W),type2,'LineWidth',3)
% hold on
% text(5,1.58,'Cr','Fontweight','bold','FontName','Times New Roman', 'FontSize',10)
% text(5,0.6,'PCr','Fontweight','bold','FontName','Times New Roman', 'FontSize',10)
%^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
% x=[0.15 0.18 ]; y=[0.28 0.26];
% txtar =  annotation('textarrow',x,y,'String','Cr','FontSize',10,'FontWeight','bold');
% x=[0.15 0.18 ]; y=[0.28 0.23];
% txtar =  annotation('textarrow',x,y);
% %^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
% x=[0.15 0.18 ]; y=[0.12 0.16];
% txtar =  annotation('textarrow',x,y,'String','PCr','FontSize',10,'FontWeight','bold');
% x=[0.15 0.18 ]; y=[0.12 0.18];
% txtar =  annotation('textarrow',x,y);
%^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
%xlabel('Time, t [min]', 'FontName','Times New Roman', 'FontSize',11,'Fontweight','bold');
title('PCr and Cr', 'FontName','Times New Roman', 'FontSize',12,'Fontweight','bold');
ylabel('unitless', 'FontName','Times New Roman', ...
      'FontSize',11,'Fontweight','bold')
hold on
% errorbar(texp_Tis_CON_3b-5, Cexp_Tis_CON_3b (:,3),...
%                Cexp_Tis_ErrorL_CON_3b (:,3), ...
%                Cexp_Tis_ErrorU_CON_3b (:,3), ...
%                'kd', 'MarkerFaceColor','k', 'MarkerSize',8, ...
%     'LineWidth',2.5)
%text(-4,1.1,'A','FontSize',15)
xlabel('Time [min]', 'FontName','Times New Roman', 'FontSize',11,'Fontweight','bold');
axis([-6 Tend-6 0.5 2]);
%axis 'autoy'
set(gca, 'LineWidth',2, 'FontName','Times New Roman', 'FontSize',10);
set(gca, 'XTick', [-5,0:5:20]);
set(gca, 'YTick', [0.5:0.5:2]);
% hold on
% errorbar(texp_Tis_CON_3b-5, Cexp_Tis_CON_3b(:,4)/2, ...
%               Cexp_Tis_ErrorL_CON_3b (:,4)/2, ...
%               Cexp_Tis_ErrorU_CON_3b (:,4)/2, ...
%               'ks', 'MarkerFaceColor','k', 'MarkerSize',8, ...
%     'LineWidth',3)
text(-4,1.9,'G','FontSize',15,'Fontweight','bold')
% legend('PCr','Cr','location','southeast')
% legend('boxoff')
text(5,1.7,'Cr','FontSize',13)
text(5,0.6,'PCr','FontSize',13)
%--------------------------------------------------------------------------
subplot(3,3,8); subplot('position',[0.38 0.06 0.28 0.26]);   % ATP
% plot(t-6,...
%      (Cc_mat_R(:,22)*V_cyt_R + Cm_mat_R(:,7)*V_mit_R+ Cc_mat_W(:,22)*V_cyt_W + Cm_mat_W(:,7)*V_mit_W)/...
%      (Cc0_R(22)*V_cyt_R + Cc0_R(36)*V_mit_R +  Cc0_W(22)*V_cyt_W + Cc0_W(36)*V_mit_W)*Cexp_Tis_CON_3b (1,2),...
%       type_t,'LineWidth',3)
% hold on
plot(t-6,(Cc_mat_R(:,22)*V_cyt_R + Cm_mat_R(:,7)*V_mit_R)/...
         (Cc0_R(22)*V_cyt_R + Cc0_R(36)*V_mit_R), type1,'LineWidth',3)
hold on
plot(t-6,(Cc_mat_W(:,22)*V_cyt_W + Cm_mat_W(:,7)*V_mit_W)/...
         (Cc0_W(22)*V_cyt_W + Cc0_W(36)*V_mit_W), type2,'LineWidth',3)
legend('Type I', 'Type II','location','southeast')     
legend('boxoff')
hold on
xlabel('Time [min]', 'FontName','Times New Roman', 'FontSize',11,'Fontweight','bold');
title('ATP', 'FontName','Times New Roman', 'FontSize',12,'Fontweight','bold');
% ylabel('C(t)/C(0)', 'FontName','Times New Roman', ...
%      'FontSize',10)
%ylabel('C_{ATP}(t) in cell [mmol/kg ww]', 'FontName','Times New Roman', 'FontSize',10);
axis([-6 Tend-6 0.5 1.3]);
%axis 'autoy'
set(gca, 'LineWidth',2, 'FontName','Times New Roman', 'FontSize',10);
set(gca, 'XTick', [-5,0:5:20]);
set(gca, 'YTick', [0.5:0.5:1.3]);
% hold on
% errorbar(texp_Tis_CON_3b-5, Cexp_Tis_CON_3b (:,2), ...
%                             Cexp_Tis_ErrorL_CON_3b (:,2),...
%                             Cexp_Tis_ErrorU_CON_3b (:,2)...
%              , 'ks', 'MarkerFaceColor','k', 'MarkerSize',8,   'LineWidth',2.5)
text(-4,1.25,'H','FontSize',15,'Fontweight','bold')
%--------------------------------------------------------------------------
subplot(3,3,9); subplot('position',[0.71 0.06 0.28 0.26]);   % NADH/NAD
% plot(t-6,...
%      ((Cc_mat_R(:,27)*V_cyt_R + Cm_mat_R(:,5)*V_mit_R+ Cc_mat_W(:,27)*V_cyt_W + Cm_mat_W(:,5)*V_mit_W)./...
%       (Cc_mat_R(:,28)*V_cyt_R + Cm_mat_R(:,6)*V_mit_R+ Cc_mat_W(:,28)*V_cyt_W + Cm_mat_W(:,6)*V_mit_W))/...     
%      ((Cc_mat_R(1,27)*V_cyt_R + Cm_mat_R(1,5)*V_mit_R+ Cc_mat_W(1,27)*V_cyt_W + Cm_mat_W(1,5)*V_mit_W)/...
%       (Cc_mat_R(1,28)*V_cyt_R + Cm_mat_R(1,6)*V_mit_R+ Cc_mat_W(1,28)*V_cyt_W + Cm_mat_W(1,6)*V_mit_W))...
%       *Cexp_Tis_CON_3b(1,5)*1000 ...
%       ,type_t,'LineWidth',3)
plot(t-6,...
     ((Cc_mat_R(:,27)*V_cyt_R + Cm_mat_R(:,5)*V_mit_R)./...
      (Cc_mat_R(:,28)*V_cyt_R + Cm_mat_R(:,6)*V_mit_R))/...     
     ((Cc_mat_R(1,27)*V_cyt_R + Cm_mat_R(1,5)*V_mit_R)/...
      (Cc_mat_R(1,28)*V_cyt_R + Cm_mat_R(1,6)*V_mit_R))...
       ,type1,'LineWidth',3)
hold on     
plot(t-6,...
     ((Cc_mat_W(:,27)*V_cyt_W + Cm_mat_W(:,5)*V_mit_W)./...
      (Cc_mat_W(:,28)*V_cyt_W + Cm_mat_W(:,6)*V_mit_W))/...     
     ((Cc_mat_W(1,27)*V_cyt_W + Cm_mat_W(1,5)*V_mit_W)/...
      (Cc_mat_W(1,28)*V_cyt_W + Cm_mat_W(1,6)*V_mit_W))... 
      ,type2,'LineWidth',3)

xlabel('Time [min]', 'FontName','Times New Roman', 'FontSize',10,'Fontweight','bold');
title('Redox State (NADH/NAD)', 'FontName','Times New Roman', 'FontSize',12,'Fontweight','bold');
%ylabel('unitless)', 'FontName','Times New Roman', 'FontSize',11,'Fontweight','bold')
axis([-6 Tend-6 0. 4]);
%axis 'autoy'
set(gca, 'LineWidth',2, 'FontName','Times New Roman', 'FontSize',10);
set(gca, 'XTick', [-5,0:5:20]);
set(gca, 'YTick', [0.:1:4]);
% hold on
% errorbar(texp_Tis_CON_3b-5, Cexp_Tis_CON_3b (:,5)*1000,...
%                             Cexp_Tis_ErrorL_CON_3b(:,5)*1000,...
%                             Cexp_Tis_ErrorU_CON_3b(:,5)*1000,...
%     'ks', 'MarkerFaceColor','k', 'MarkerSize',8,   'LineWidth',2.5)
text(-4, 3.68, 'I','FontSize',15,'Fontweight','bold')
% 
% hold on



%=========================================================================

%*******************************************************************************
  %                              END

%*****************************************************************************
