%*******************************************************************************
function [Vmaxf, Vmaxb]= Sub_A_Vmax_H(Vmaxf, Vmaxb, Kf, Kb,pH_c, pH_m,Keq_0)
%*******************************************************************************
% This subroutine is to calculate the Vmaxf and Vmaxb according to the change of 
% proton and pH.
%--------------------------------------------------------------------------
% Because Proton is incorporated in the model, which can affect the free
% energy and influence reaction rate. Therefore, it's need to recalculate the 
% Vmaxf and Vmaxb correspondingly during dynamic process

% Note: not all reaction need to be involved.  Here we assume the Kf and Kb
% are constant, and set Vmaxf and recalculate Vmaxb

% Modified on Jun 4, 2009.
%*******************************************************************************
format long

%******************************************************************************
%                         Reaction in cytosol 
%******************************************************************************

%1 Hexokinase:                 Glc + ATP-> G6P+ADP +H
Keq(1) = Keq_0(1)/10^(7.1-pH_c);
Vmaxb(1) =(Vmaxf(1)*Kb(1))/(Kf(1)*Keq(1)); 

%2Phosphoglucomutase:         G1P<---> G6P 
Keq(2) = Keq_0(2)/10^(7.1-pH_c);
Vmaxb(2) =(Vmaxf(2)*Kb(2))/(Kf(2)*Keq(2)); 

%3 UDP-glucose pyrophosphorylase +glycogen synthase:  G1P + ATP + Gly_n + H2O-> Gly_n+1 + ADP+ 2Pi
Keq(3) = Keq_0(3)/10^(7.1-pH_c);
Vmaxb(3) =(Vmaxf(3)*Kb(3))/(Kf(3)*Keq(3)); 

%4 Glycogen phosphorylase:      Gly(n+1)+Pi->Gly(n)+ G1P
Keq(4) = Keq_0(4)/10^(7.1-pH_c);
Vmaxb(4) =(Vmaxf(4)*Kb(4))/(Kf(4)*Keq(4)); 

%5 Phosphoglucose isomerase:   G6P->F6P
Keq(5) = Keq_0(5)/10^(7.1-pH_c);
Vmaxb(5) =(Vmaxf(5)*Kb(5))/(Kf(5)*Keq(5)); 

%6 Phosphofructokinase:        F6P+ATP->F16BP+ADP+H
Keq(6) = Keq_0(6)/10^(7.1-pH_c);
Vmaxb(6) =(Vmaxf(6)*Kb(6))/(Kf(6)*Keq(6)); 

% Aldolase +Triose phosphate isomerase      F16BP<--->2GA3P
Keq(7) = Keq_0(7)/10^(7.1-pH_c);
Vmaxb(7) =(Vmaxf(7)*Kb(7))/(Kf(7)*Keq(7)); 

%8 Glyceraldehyde 3-phosphate dehydrogenase: GA3P+Pi+NAD->13BPG+NADH + H
Keq(8) = Keq_0(8)/10^(7.1-pH_c);
Vmaxb(8) =(Vmaxf(8)*Kb(8))/(Kf(8)*Keq(8)); 

% Phosphoglycerate kinase:     13BPG +ADP-> PEP +ATP +H2O
Keq(9) = Keq_0(9)/10^(7.1-pH_c);
Vmaxb(9) =(Vmaxf(9)*Kb(9))/(Kf(9)*Keq(9)); 

%10 Pyruvate kinase:              PEP + ADP + H<--->Pyr +ATP
Keq(10) = Keq_0(10)/10^(7.1-pH_c);
Vmaxb(10) =(Vmaxf(10)*Kb(10))/(Kf(10)*Keq(10)); 

%11 Lactate dehydrogenase:        Pyr+NADH+H -> Lac+NAD
Keq(11) = Keq_0(11)/10^(7.1-pH_c);
Vmaxb(11) =(Vmaxf(11)*Kb(11))/(Kf(11)*Keq(11)); 

%12 Lipases:                      TGl -> 3FFA + Glr + 3H 
Keq(12) = Keq_0(12)/10^(7.1-pH_c);
Vmaxb(12) =(Vmaxf(12)*Kb(12))/(Kf(12)*Keq(12)); 

%13 Glycerol 3-phosphate dehydrogenase:  GA3P + NADH + H-> G3P+NAD
Keq(13) = Keq_0(13)/10^(7.1-pH_c);
Vmaxb(13) =(Vmaxf(13)*Kb(13))/(Kf(13)*Keq(13)); 

% Acyltransferase:              G3P+3FAC->Tgl+3CoA +Pi
Keq(14) = Keq_0(14)/10^(7.1-pH_c);
Vmaxb(14) =(Vmaxf(14)*Kb(14))/(Kf(14)*Keq(14)); 

%15 Acyl-CoA synthetase:          FFA +CoA +2ATP ->FAC+2ADP+2Pi+2H
Keq(15) = Keq_0(15)/10^(7.1-pH_c);
Vmaxb(15) =(Vmaxf(15)*Kb(15))/(Kf(15)*Keq(15)); 

%16 ATPase:                       ATP -> ADP + Pi + H+
Keq(16) = Keq_0(16)/10^(7.1-pH_c);
Vmaxb(16) =(Vmaxf(16)*Kb(16))/(Kf(16)*Keq(16)); 

% Adenylate kinase:             ATP + AMP<-> 2ADP
% Acyltransferase:              G3P+3FAC->Tgl+3CoA +Pi
Keq(17) = Keq_0(17)/10^(7.1-pH_c);
Vmaxb(17) =(Vmaxf(17)*Kb(17))/(Kf(17)*Keq(17)); 

%18 Creatine kinase:              PCr + ADP + H <-> Cr+ATP
Keq(18) = Keq_0(18)/10^(7.1-pH_c);
Vmaxb(18) =(Vmaxf(18)*Kb(18))/(Kf(18)*Keq(18)); 

% Alanine aminotransferase:       Pyr+Glu-> Ala +AKG
Keq(19) = Keq_0(19)/10^(7.1-pH_c);
Vmaxb(19) =(Vmaxf(19)*Kb(19))/(Kf(19)*Keq(19)); 
%******************************************************************************
%                   Reaction in mitochondria 
%******************************************************************************
%20 Pyruvate dehydrogenase:         Pyr +H2O+CoA+NAD<--->NADH + ACoA +CO2 +H
Keq(20) = Keq_0(20)/10^(7.6-pH_m);
Vmaxb(20) =(Vmaxf(20)*Kb(20))/(Kf(20)*Keq(20)); 

%21 Fatty acyl-CoA oxidation:       FAC + 7CoA + 7NAD+7FAD -> 8ACoA + 7NADH + 7FADH2 + 7H
Keq(21) = Keq_0(21)/10^(7.6-pH_m);
Vmaxb(21) =(Vmaxf(21)*Kb(21))/(Kf(21)*Keq(21)); 

%22 Citrate synthase:               ACoA + Oxa-> Cit +CoA + H
Keq(22) = Keq_0(22)/10^(7.6-pH_m);
Vmaxb(22) =(Vmaxf(22)*Kb(22))/(Kf(22)*Keq(22)); 

% Isocitrate dehydrogenase:       Cit + NAD+H2O-> AKG +NADH + CO2
Keq(23) = Keq_0(23)/10^(7.6-pH_m);
Vmaxb(23) =(Vmaxf(23)*Kb(23))/(Kf(23)*Keq(23)); 

% a-Ketoglutarate dehydrogenase:  AKG + CoA + NAD -> SCoA + NADH + CO2
Keq(24) = Keq_0(24)/10^(7.6-pH_m);
Vmaxb(24) =(Vmaxf(24)*Kb(24))/(Kf(24)*Keq(24)); 

% Succinyl-CoA synthetase:        SCoA + ADP +Pi -> Suc +CoA +ATP+CO2
Keq(25) = Keq_0(25)/10^(7.6-pH_m);
Vmaxb(25) =(Vmaxf(25)*Kb(25))/(Kf(25)*Keq(25)); 

% Succinate dehydrogenase:        Succ +FAD+H2O -> Mal +FADH2
Keq(26) = Keq_0(26)/10^(7.6-pH_m);
Vmaxb(26) =(Vmaxf(26)*Kb(26))/(Kf(26)*Keq(26)); 

%27 Malate dehydrogenase:           Mal + NAD-> Oxa +NADH + H+
Keq(27) = Keq_0(27)/10^(7.6-pH_m);
Vmaxb(27) =(Vmaxf(27)*Kb(27))/(Kf(27)*Keq(27)); 

%28 Complex 1:               NADH + H +0.5O2->NAD + H2O
Keq(28) = Keq_0(28)/10^(7.6-pH_m);
Vmaxb(28) =(Vmaxf(28)*Kb(28))/(Kf(28)*Keq(28)); 

% Complex 2:               FADH2+ H +0.5O2->FAD + H2O 
Keq(29) = Keq_0(29)/10^(7.6-pH_m);
Vmaxb(29) =(Vmaxf(29)*Kb(29))/(Kf(29)*Keq(29)); 

%30 ATP Synthase:            H + ADP + Pi+ 3delataH ->ATP
Keq(30) = Keq_0(30)/10^(7.6-pH_m);
Vmaxb(30) =(Vmaxf(30)*Kb(30))/(Kf(30)*Keq(30)); 

%******************************************************************************
%                  END OF THE Subroutine
%******************************************************************************
