%**************************************************************************
% This subroutine is to perform flux balance analysis (FBA) in each fiber
% based on the available experimental data of URR at resting steady state. 
%**************************************************************************

function [Rflux,URR]= Sub_FluxBalance(URR)

Rflux =zeros(31,1);           
%--------------------------------------------------------------------------
%                   Flux in Cytosol -Glycolysis 
%--------------------------------------------------------------------------
% Hexokinase:                  Glc + ATP -> G6P + ADP + H+
Rflux(1) =URR(1);              % from Glucose flux balance equation
% Phosphoglucomutase:          G1P  <-> G6P (no use)
Rflux(2) = 0;                  % net flux is 0 at steady state
% UDP-glucose pyrophosphorylase +glycogen synthase:  G1P + ATP + Gly(n) ->ADP+ Gly(n+1) + 2Pi
Rflux(3) = 0.25;               % Assumption 
%Glycogen phosphorylase:       Gly(n+1)+Pi->Gly(n)+ G1P
Rflux(4) = Rflux(3); 
% Phosphoglucose isomerase:    G6P->F6P
Rflux(5) = Rflux(1);
% Phosphofructokinase:         F6P+ATP->F16BP+ADP+H
Rflux(6) = Rflux(5);
% Aldolase:                    F16BP<--->2GA3P
Rflux(7) = Rflux(6);
% Glyceraldehyde 3-phosphate dehydrogenase: GA3P + Pi + NAD ->13BPG + NADH + H
Rflux(8) = 2*Rflux(7) +URR(5);
% Phosphoglycerate kinase:     13BPG + ADP -> PEP + ATP + H2O
Rflux(9) = Rflux(8);
% Pyruvate kinase:              PEP + AD P+ H+ -> Pyr +ATP
Rflux(10) = Rflux(9);           % flux equal to 2URR((1)+URR((5)  
% Lactate dehydrogenase:        Pyr+NADH+H -> Lac+NAD
Rflux(11) = -URR(3);            % Literature, equal to 'Lactate release rate'      
%--------------------------------------------------------------------------
%                   Flux in Cytosol -Lipid Metabolism
%--------------------------------------------------------------------------
% Lipases:                      Tgl->Glc+3FFA+3H
Rflux(12) = -URR(5);            % Literature, equal to Glycerol release rate 
% Glycerol 3-phosphate dehydrogenase:  GA3P+NADH+H-> Gr3P+NAD
Rflux(13) = -URR(5);            % Choose equal to Glycerol release to keep Triglyceride balance  
% Acyltransferase:              Gr3P+3FAC->Tgl+3CoA +Pi
Rflux(14) = Rflux(13); 
% Acyl-CoA synthetase:          FFA +CoA +2ATP ->FAC+2ADP+2Pi+2H
Rflux(15) = 3*Rflux(12) +URR(6); 
%--------------------------------------------------------------------------
%                    Flux in Cytosol -Energetics:
%--------------------------------------------------------------------------
% ATPase:                       ATP->ADP+Pi+H
% Note: the ATPase flux is determined from ATP balance based upon the NADH and FADH2 balance 
Rflux(16) = 32*URR(1) + 12.5*URR(2) + 15*URR(3) + 106*URR(6) + 12.5* URR(4) + 25.5*URR(5) -Rflux(3);
% Adenylate kinase:              ATP+AMP<->2ADP
Rflux(17) = 0;       
% Creatine kinase:              PCr+ADP+H <-> Cr+ATP
Rflux(18) = 0;                  %Equilibrium at rest condition 
%--------------------------------------------------------------------------
%                    Flux in Cytosol -Amino Acid Metabolism
%--------------------------------------------------------------------------
% Alanine aminotransferase:       Pyr -> Ala 
Rflux(19) = -URR(4);              %Literature, equatl to Alanine release 
%--------------------------------------------------------------------------
%                 Fluxes in Mitochondria into TCA Cycle
%--------------------------------------------------------------------------
% Pyruvate dehydrogenase:         PYR + CoA + NAD -> ACoA + NADH + CO2 +H
Rflux(20) =URR(2)+ Rflux(10) - Rflux(11)- Rflux(19); % flux equals to 2URR((1)+URR(5) +URR(2)+URR((3)+URR((4)
% Fatty acyl-CoA oxidation:         FAC + 7CoA + 7NAD+7FAD -> 8ACoA + 7NADH + 7FADH2 + 7H
Rflux(21) = Rflux(15)- 3*Rflux(14); %Flux equals toURR(6)+ x
%--------------------------------------------------------------------------
%            Fluxes in Mitochondria - TCA Cycle
%--------------------------------------------------------------------------
% Citrate synthase:               ACoA + OXA -> CIT + CoA+ H
Rflux(22) = 8*Rflux(21) + Rflux(20);  %flux equals to 8URR((4)+2URR((1)+URR((6) +URR(5)+URR((2)+URR((3)
% Isocitrate dehydrogenase:       Cit+NAD->AKG+CO2+NADH
Rflux(23) = Rflux(22)+URR(42);    %1% citrate are assumed to release to cytosol 
% a-Ketoglutarate dehydrogenase:  AKG + CoA + NAD -> SCoA + NADH + CO2
Rflux(24) = Rflux(23);
% Succinyl-CoA synthetase:        SCoA+ADP+Pi->Suc+CoA+ATP
Rflux(25) = Rflux(24);
% Succinate dehydrogenase:        Suc+FAD->Mal+FADH2
Rflux(26) = Rflux(25);
% Malate dehydrogenase:           MAL + NAD -> OXA + NADH +H
Rflux(27) = Rflux(26) +URR(46);
%--------------------------------------------------------------------------
%               Fluxes in Mitochondria -Oxidative Phosphorylation 
%--------------------------------------------------------------------------
% Complex 1:               NADH+H+1/2 O2-> NAD+H2O
Rflux(28) = 7*Rflux(21) + Rflux(20)+ 2* Rflux(24)+ Rflux(27)+ Rflux(8) - Rflux(13)-Rflux(11);  
            % the first three terms are fluxes of NADH production in Mitochondria, and 
            % last four terms are fluxes of net NADH uptake from cytosol 
            % Flux equals to 10*URR((1) + 4*URR((2)+ 5*URR((3)+ 31*URR((6)+ 4*URR((4)+ 6*URR((5)  original 
            % here assume all NADH are consumed in ETC
% Complex 2:               FADH2+ 0.5O2 ->FAD + H2O  
Rflux(29) = 7*Rflux(21) + Rflux(26); 
            %Ass. all FADH2 consumed in ETC
            %Flux equals to %2*URR((1) +URR(2)+URR(3)+URR(4)+URR(5)+ 15*URR((6) original 
% ATP Synthase:            H + ADP + Pi+ 3delataH ->ATP
Rflux(30) = 2.5 * Rflux(28) + 1.5 * Rflux(29); 
            % Assume the efficiency is: 1 NADH: 2.5ATP, 1 FADH2: 1.5NADH 
            % Assume all ATP synthsized would be moved to Cytosol 
            % 28*URR(1)+11.5*URR(2)+14*URR(3)+11.5*URR(4)+16.5*URR(5)+100*URR(6)  
%note: Here just estimate the Proton transport flux. In the present model,
%H are assumed as constant and Proton transport is not considered. 
% H leakage
Rflux(31) = 10*Rflux(28) +6*Rflux(29)- 3*Rflux(30);
            % Here assume 1NADH-> 10H and 1FADH2-> 6H, total 10Rflux(28) + 6Rflux(29);
            % Note here 2.8 H+ are needed for 1 ATP synthesis,then total
            % 2.8Rflux(30) and others are assumed to be leakage and ATP transport to keep mass balance
%Note: although Malonyl CoA can synthesis FFA, but it make the flux balance
%difficult, Temporarily define a 1st order equation for utilization.
%******************************************************************************
% This section sets the exchanges fluxes involving transport between
% cytosol and mitochondria. All of the fluxes are not independent and based
% on above flux balance 
%******************************************************************************
URR(30) = URR(8);                                   % O2 enter mitocndria
URR(31) = URR(7);                                   % CO2 release from mitochndria 
URR(32) = URR(2)+ Rflux(10) - Rflux(11)- Rflux(19); % Pyruvate enter mitochndria 
URR(33) = URR(6);                                   % Fatty Acyl-CoA enter mitochondria
URR(34) = Rflux(8)-Rflux(13)-Rflux(11);             % NADH produced in Cytosol entering mitochondria   
URR(35) = -URR(34);                                 % NAD enter mitochondria
URR(36) = -(30*URR(1) + 12.5*URR(2) + 15*URR(3) + 12.5*URR(4) + 17.5*URR(5) + 108*URR(6));  % ATP leave mitochondria  original 
URR(37) = -URR(36);                                 % ADP enter mitochondria 
URR(38) = URR(37);                                  % Pi enter mitochondria 
URR(39) =  -URR(6);                                 % CoA leave mitochondria   

% ==========================================================================
% This section calcuate the transport rate of proton between blood and
% cytosola and between cytosol and mitochondria
% --------------------------------------------------------------------------
Beta_c = 5.339903806083854; %6.65774778586762;                           % Buffer capacity in cytosol
Beta_m = 25;                                         % Buffer capacity in mito  
Cc_H_c = 7.94328234724282e-005;                      % H in cytosol 
Cc_H_m = 2.51188643150958e-005;                      % H in mitochondria 
%--------------------------------------------------------------------------
H_P_c = Rflux(1)+Rflux(6)+Rflux(8)+3*Rflux(12)+2*Rflux(15)+Rflux(16);   %H produced in Cytosol
H_U_c = Rflux(10)+Rflux(11)+Rflux(13)+Rflux(18);                        %H utilized in cytosol  New Rflux(34) 
P_net_c =H_P_c -H_U_c ;                                                 %Net metabolic rate in cytosol 

% 
H_P_m = Rflux(20) + 7*Rflux(21)+ Rflux(22) + Rflux(27);                 %H produced in mito
H_U_m = Rflux(28) +Rflux(30);                                           %H utilized in mito
P_net_m= H_P_m-H_U_m;                                                   %net metabolic rate in mito.                 
 
URR(40)= -(H_P_m- H_U_m)*Cc_H_m*2.303/Beta_m;                           %H transport from cytosol to mito
URR(29)= URR(40) -2.303*Cc_H_c*(P_net_c-Rflux(31))/Beta_c;              %H transport from cytosol to blood

 %--------------------------------------------------------------------------
%                  Balance of proton
%------------------------
% AV difference in whole muscle
% URR_H= Qm* (Ca(9) - Cb(9))
%--------------------------------------------------------------------------
%                      Type I 
% H_P_c_R = Rflux_R(1)+Rflux_R(6)+Rflux_R(8)+3*Rflux_R(12)+2*Rflux_R(15)+Rflux_R(16); %H produced in Cytosol
% H_U_c_R = Rflux_R(10)+Rflux_R(11)+Rflux_R(13)+Rflux_R(18)+Rflux_R(31);              %H utilized in cytosol  New Rflux(31) 
% P_net_c_R =H_P_c_R -H_U_c_R;                                                        %Net metabolic rate in cytosol 
% 
% 
% 
% H_P_m_R = Rflux_R(20) + 7*Rflux_R(21)+ Rflux_R(22) + Rflux_R(27);            %H produced in mito
% H_U_m_R = Rflux_R(28) +Rflux_R(30);                                          %H utilized in mito
% P_net_m_R= H_P_m_R - H_U_m_R;                                                %net metabolic rate in mito.                 
% 
% Beta_c =6.65774778586762;       % Buffer capacity in cytosol
% Beta_m =25;                     % Buffer capacity in mito  
% 
% URR_R(40)= -(H_P_m_R- H_U_m_R)*Cc_R(40)*2.303/Beta_m;            %H transport from cytosol to mito
% URR_R(29)= URR_R(40) -2.303*Cc_R(29)*P_net_c_R/Beta_c;
% %--------------------------------------------------------------------------
% %--------------------------------------------------------------------------
% %                      Type II 
% H_P_c_W = Rflux_W(1)+Rflux_W(6)+Rflux_W(8)+3*Rflux_W(12)+2*Rflux_W(15)+Rflux_W(16); %H produced in Cytosol
% H_U_c_W = Rflux_W(10)+Rflux_W(11)+Rflux_W(13)+Rflux_W(18)+Rflux_W(31);              %H utilized in cytosol  New Rflux(31) 
% P_net_c_W =H_P_c_W -H_U_c_W;                                                        %Net metabolic rate in cytosol 
% 
% 
% 
% H_P_m_W = Rflux_W(20) + 7*Rflux_W(21)+ Rflux_W(22) + Rflux_W(27);            %H produced in mito
% H_U_m_W = Rflux_W(28) +Rflux_W(30);                                          %H utilized in mito
% P_net_m_W= H_P_m_W - H_U_m_W;                                                %net metabolic rate in mito.                 
% 
% Beta_c =6.65774778586762;       % Buffer capacity in cytosol
% Beta_m =25;                     % Buffer capacity in mito  
% 
% URR_W(40)= -(H_P_m_W- H_U_m_W)*Cc_W(40)*2.303/Beta_m;            %H transport from cytosol to mito
% URR_W(29)= URR_W(40) -2.303*Cc_W(29)*P_net_c_W/Beta_c;
% 
% bbb= -(2.303*Cc_R(29)*P_net_c_R+2.303*Cc_W(29)*P_net_c_W)/(URR_H- (URR_R(40)+URR_W(40)))
% 




